"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QScroller(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qscroller.html

    **Detailed Description**

    With kinetic scrolling, the user can push the widget in a given direction
    and it will continue to scroll in this direction until it is stopped either
    by the user or by friction. Aspects of inertia, friction and other physical
    concepts can be changed in order to fine-tune an intuitive user experience.

    The QScroller object is the object that stores the current position and
    scrolling speed and takes care of updates. QScroller can be triggered by a
    flick gesture

    **QWidget**  *w = ...;
            QScroller::grabGesture(w,
    QScroller::LeftMouseButtonGesture);

    or directly like this:

    **QWidget**  *w = ...;
            QScroller *scroller = QScroller::scroller(w);
    scroller->scrollTo(**QPointF** (100, 100));

    The scrolled QObjects receive a **QScrollPrepareEvent**  whenever the
    scroller needs to update its geometry information and a **QScrollEvent**
    whenever the content of the object should actually be scrolled.

    The scroller uses the global **QAbstractAnimation**  timer to generate its
    QScrollEvents. This can be changed with **QScrollerProperties::FrameRate**
    on a per-QScroller basis.

    The **Dir View Example**  shows one way to use a QScroller with a
    **QTreeView** . An example in the `scroller` examples directory also
    demonstrates QScroller.

    Even though this kinetic scroller has a large number of settings available
    via **QScrollerProperties** , we recommend that you leave them all at their
    default, platform optimized values. Before changing them you can experiment
    with the `plot` example in the `scroller` examples directory.

    **See also** **QScrollEvent** , **QScrollPrepareEvent** , and
    **QScrollerProperties** .
    """

    class Input(enum.Enum):
        InputPress: QScroller = ...
        InputMove: QScroller = ...
        InputRelease: QScroller = ...

    class ScrollerGestureType(enum.Enum):
        TouchGesture: QScroller = ...
        LeftMouseButtonGesture: QScroller = ...
        RightMouseButtonGesture: QScroller = ...
        MiddleMouseButtonGesture: QScroller = ...

    class State(enum.Enum):
        Inactive: QScroller = ...
        Pressed: QScroller = ...
        Dragging: QScroller = ...
        Scrolling: QScroller = ...

    def resendPrepareEvent(self) -> None:
        """
        https://doc.qt.io/qt-6/qscroller.html#resendPrepareEvent

        **[slot] void QScroller::resendPrepareEvent()**

        This function resends the **QScrollPrepareEvent** . Calling
        resendPrepareEvent triggers a **QScrollPrepareEvent**  from the
        scroller. This allows the receiver to re-set content position and
        content size while scrolling. Calling this function while in the
        Inactive state is useless as the prepare event is sent again before
        scrolling starts.
        """
        ...

    @typing.overload
    def ensureVisible(
        self, rect: QtCore.QRectF, xmargin: float, ymargin: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qscroller.html#ensureVisible

        **[slot] void QScroller::ensureVisible(const QRectF & rect , qreal
        xmargin , qreal ymargin )**

        Starts scrolling so that the rectangle **rect** is visible inside the
        viewport with additional margins specified in pixels by **xmargin** and
        **ymargin** around the rect.

        In cases where it is not possible to fit the rect plus margins inside
        the viewport the contents are scrolled so that as much as possible is
        visible from **rect**.

        The scrolling speed is calculated so that the given position is reached
        after a platform-defined time span.

        This function performs the actual scrolling by calling **scrollTo** ().

        **See also** **scrollTo** ().
        """
        ...

    @typing.overload
    def ensureVisible(
        self, rect: QtCore.QRectF, xmargin: float, ymargin: float, scrollTime: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qscroller.html#ensureVisible-1

        **[slot] void QScroller::ensureVisible(const QRectF & rect , qreal
        xmargin , qreal ymargin , int scrollTime )**

        This is an overloaded function.

        This version will reach its destination position in **scrollTime**
        milliseconds.
        """
        ...

    @typing.overload
    def scrollTo(self, pos: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qscroller.html#scrollTo

        **[slot] void QScroller::scrollTo(const QPointF & pos )**

        Starts scrolling the widget so that point **pos** is at the top-left
        position in the viewport.

        The behaviour when scrolling outside the valid scroll area is undefined.
        In this case the scroller might or might not overshoot.

        The scrolling speed will be calculated so that the given position will
        be reached after a platform-defined time span.

        **pos** is given in viewport coordinates.

        **See also** **ensureVisible** ().
        """
        ...

    @typing.overload
    def scrollTo(self, pos: QtCore.QPointF, scrollTime: int) -> None:
        """
        https://doc.qt.io/qt-6/qscroller.html#scrollTo-1

        **[slot] void QScroller::scrollTo(const QPointF & pos , int scrollTime
        )**

        This is an overloaded function.

        This version will reach its destination position in **scrollTime**
        milliseconds.
        """
        ...

    def setScrollerProperties(self, prop: "QScrollerProperties") -> None:
        """
        https://doc.qt.io/qt-6/qscroller.html#scrollerProperties-prop

        **scrollerProperties : QScrollerProperties**

        This property holds the scroller properties of this scroller. The
        properties are used by the **QScroller**  to determine its scrolling
        behavior.

        **Access functions:**

        QScrollerProperties **scrollerProperties** () const
        void
        **setScrollerProperties** (const QScrollerProperties & **prop** )

        **Notifier signal:**

        void ****scrollerPropertiesChanged** ** (const QScrollerProperties &
        **newProperties** )
        """
        ...

    @typing.overload
    def setSnapPositionsY(self, positions: typing.Iterable[float]) -> None:
        """
        https://doc.qt.io/qt-6/qscroller.html#setSnapPositionsY

        **void QScroller::setSnapPositionsY(const QList<qreal> & positions )**

        Set the snap positions for the vertical axis to a list of **positions**.
        This overwrites all previously set snap positions and also a previously
        set snapping interval. Snapping can be deactivated by setting an empty
        list of positions.
        """
        ...

    @typing.overload
    def setSnapPositionsY(self, first: float, interval: float) -> None:
        """
        https://doc.qt.io/qt-6/qscroller.html#setSnapPositionsY-1

        **void QScroller::setSnapPositionsY(qreal first , qreal interval )**

        Set the snap positions for the vertical axis to regular spaced
        intervals. The first snap position is at **first**. The next at
        **first** \\+ **interval**. This overwrites all previously set snap
        positions and also a previously set snapping interval. Snapping can be
        deactivated by setting an interval of 0.0
        """
        ...

    @typing.overload
    def setSnapPositionsX(self, positions: typing.Iterable[float]) -> None:
        """
        https://doc.qt.io/qt-6/qscroller.html#setSnapPositionsX

        **void QScroller::setSnapPositionsX(const QList<qreal> & positions )**

        Set the snap positions for the horizontal axis to a list of
        **positions**. This overwrites all previously set snap positions and
        also a previously set snapping interval. Snapping can be deactivated by
        setting an empty list of positions.
        """
        ...

    @typing.overload
    def setSnapPositionsX(self, first: float, interval: float) -> None:
        """
        https://doc.qt.io/qt-6/qscroller.html#setSnapPositionsX-1

        **void QScroller::setSnapPositionsX(qreal first , qreal interval )**

        Set the snap positions for the horizontal axis to regular spaced
        intervals. The first snap position is at **first**. The next at
        **first** \\+ **interval**. This can be used to implement a list header.
        This overwrites all previously set snap positions and also a previously
        set snapping interval. Snapping can be deactivated by setting an
        interval of 0.0
        """
        ...

    def scrollerProperties(self) -> "QScrollerProperties":
        """
        https://doc.qt.io/qt-6/qscroller.html#scrollerProperties-prop

        **scrollerProperties : QScrollerProperties**

        This property holds the scroller properties of this scroller. The
        properties are used by the **QScroller**  to determine its scrolling
        behavior.

        **Access functions:**

        QScrollerProperties **scrollerProperties** () const
        void
        **setScrollerProperties** (const QScrollerProperties & **prop** )

        **Notifier signal:**

        void ****scrollerPropertiesChanged** ** (const QScrollerProperties &
        **newProperties** )
        """
        ...

    def pixelPerMeter(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qscroller.html#pixelPerMeter

        **QPointF QScroller::pixelPerMeter() const**

        Returns the pixel per meter metric for the scrolled widget.

        The value is reported for both the x and y axis separately by using a
        **QPointF** .

        **Note:** Please note that this value should be physically correct. The
        actual DPI settings that Qt returns for the display may be reported
        wrongly on purpose by the underlying windowing system, for example on
        macOS.
        """
        ...

    def finalPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qscroller.html#finalPosition

        **QPointF QScroller::finalPosition() const**

        Returns the estimated final position for the current scroll movement.
        Returns the current position if the scroller state is not Scrolling. The
        result is undefined when the scroller state is Inactive.

        The target position is in pixel.

        **See also** **pixelPerMeter** () and **scrollTo** ().
        """
        ...

    def velocity(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qscroller.html#velocity

        **QPointF QScroller::velocity() const**

        Returns the current scrolling velocity in meter per second when the
        state is Scrolling or Dragging. Returns a zero velocity otherwise.

        The velocity is reported for both the x and y axis separately by using a
        **QPointF** .

        **See also** **pixelPerMeter** ().
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qscroller.html#stop

        **void QScroller::stop()**

        Stops the scroller and resets its state back to Inactive.
        """
        ...

    def handleInput(
        self, input: "QScroller.Input", position: QtCore.QPointF, timestamp: int = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qscroller.html#handleInput

        **bool QScroller::handleInput(QScroller::Input input , const QPointF &
        position , qint64 timestamp = 0)**

        This function is used by gesture recognizers to inform the scroller
        about a new input event. The scroller changes its internal **state** ()
        according to the input event and its attached scroller properties. The
        scroller doesn't distinguish between the kind of input device the event
        came from. Therefore the event needs to be split into the **input**
        type, a **position** and a milli-second **timestamp**. The **position**
        needs to be in the target's coordinate system.

        The return value is `true` if the event should be consumed by the
        calling filter or `false` if the event should be forwarded to the
        control.

        **Note:** Using **grabGesture** () should be sufficient for most use
        cases.
        """
        ...

    def state(self) -> "QScroller.State":
        """
        https://doc.qt.io/qt-6/qscroller.html#state-prop

        **[read-only] state : const State**

        This property holds the state of the scroller

        **Access functions:**

        QScroller::State **state** () const

        **Notifier signal:**

        void ****stateChanged** ** (QScroller::State **newState** )

        **See also** **QScroller::State** .

        **Member Function Documentation**
        """
        ...

    def target(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qscroller.html#target

        **QObject *QScroller::target() const**

        Returns the target object of this scroller.

        **See also** **hasScroller** () and **scroller** ().
        """
        ...

    @staticmethod
    def activeScrollers() -> typing.List["QScroller"]:
        """
        https://doc.qt.io/qt-6/qscroller.html#activeScrollers

        **[static] QList<QScroller *> QScroller::activeScrollers()**

        Returns an application wide list of currently active **QScroller**
        objects. Active **QScroller**  objects are in a **state** () that is not
        **QScroller::Inactive** . This function is useful when writing your own
        gesture recognizer.
        """
        ...

    @staticmethod
    def ungrabGesture(target: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qscroller.html#ungrabGesture

        **[static] void QScroller::ungrabGesture(QObject * target )**

        Ungrabs the gesture for the **target**. Does nothing if no gesture is
        grabbed.

        **See also** **grabGesture** () and **grabbedGesture** ().
        """
        ...

    @staticmethod
    def grabbedGesture(target: QtCore.QObject) -> QtCore.Qt.GestureType:
        """
        https://doc.qt.io/qt-6/qscroller.html#grabbedGesture

        **[static] Qt::GestureType QScroller::grabbedGesture(QObject * target
        )**

        Returns the gesture type currently grabbed for the **target** or 0 if no
        gesture is grabbed.

        **See also** **grabGesture** () and **ungrabGesture** ().
        """
        ...

    @staticmethod
    def grabGesture(
        target: QtCore.QObject, scrollGestureType: "QScroller.ScrollerGestureType" = ...
    ) -> QtCore.Qt.GestureType:
        """
        https://doc.qt.io/qt-6/qscroller.html#grabGesture

        **[static] Qt::GestureType QScroller::grabGesture(QObject * target ,
        QScroller::ScrollerGestureType scrollGestureType = TouchGesture)**

        Registers a custom scroll gesture recognizer, grabs it for the
        **target** and returns the resulting gesture type. If
        **scrollGestureType** is set to **TouchGesture**  the gesture triggers
        on touch events. If it is set to one of **LeftMouseButtonGesture** ,
        **RightMouseButtonGesture**  or **MiddleMouseButtonGesture**  it
        triggers on mouse events of the corresponding button.

        Only one scroll gesture can be active on a single object at the same
        time. If you call this function twice on the same object, it will ungrab
        the existing gesture before grabbing the new one.

        **Note:** To avoid unwanted side-effects, mouse events are consumed
        while the gesture is triggered. Since the initial mouse press event is
        not consumed, the gesture sends a fake mouse release event at the global
        position `(INT_MIN, INT_MIN)`. This ensures that internal states of the
        widget that received the original mouse press are consistent.

        **See also** **ungrabGesture** () and **grabbedGesture** ().
        """
        ...

    @staticmethod
    def scroller(target: QtCore.QObject) -> "QScroller":
        """
        https://doc.qt.io/qt-6/qscroller.html#scroller

        **[static] QScroller *QScroller::scroller(QObject * target )**

        Returns the scroller for the given **target**. As long as the object
        exists this function will always return the same **QScroller**
        instance. If no **QScroller**  exists for the **target** , one will
        implicitly be created. At no point more than one **QScroller**  will be
        active on an object.

        **See also** **hasScroller** () and **target** ().
        """
        ...

    @staticmethod
    def hasScroller(target: QtCore.QObject) -> bool:
        """
        https://doc.qt.io/qt-6/qscroller.html#hasScroller

        **[static] bool QScroller::hasScroller(QObject * target )**

        Returns `true` if a **QScroller**  object was already created for
        **target** ; `false` otherwise.

        **See also** **scroller** ().
        """
        ...

    @property
    def scrollerPropertiesChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qscroller.html#scrollerPropertiesChanged

        **[signal] void QScroller::scrollerPropertiesChanged(const
        QScrollerProperties & newProperties )**

        **QScroller**  emits this signal whenever its scroller properties
        change. **newProperties** are the new scroller properties.

        **Note:** Notifier signal for property **scrollerProperties** .

        **See also** **scrollerProperties** .
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qscroller.html#stateChanged

        **[signal] void QScroller::stateChanged(QScroller::State newState )**

        **QScroller**  emits this signal whenever the state changes.
        **newState** is the new State.

        **Note:** Notifier signal for property **state** .

        **See also** **state** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtPositioning import *
import enum


class QGeoAreaMonitorSource(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qgeoareamonitorsource.html

    **Detailed Description**

    A QGeoAreaMonitorSource emits signals when the current position is in range,
    or has moved out of range, of a specified area. Each area is specified by a
    **QGeoAreaMonitorInfo**  object. For example:

    public:
            MyClass() : **QObject** ()
            {
    **QGeoAreaMonitorSource**  *monitor = **QGeoAreaMonitorSource**
    ::createDefaultSource(this);
                if (monitor) {
    connect(monitor, SIGNAL(areaEntered(**QGeoAreaMonitorInfo**
    ,**QGeoPositionInfo** )),
                            this,
    SLOT(areaEntered(**QGeoAreaMonitorInfo** ,**QGeoPositionInfo** )));
    connect(monitor, SIGNAL(areaExited(**QGeoAreaMonitorInfo**
    ,**QGeoPositionInfo** )),
                            this,
    SLOT(areaExited(**QGeoAreaMonitorInfo** ,**QGeoPositionInfo** )));
    **QGeoAreaMonitorInfo**  bigBen("Big Ben");
    **QGeoCoordinate**  position(51.50104, -0.124632);
    bigBen.setArea(**QGeoCircle** (position, 100));
    monitor->startMonitoring(bigBen);

                } else {
    **qDebug** () << "Could not create default area monitor";
                }
    }

        public Q_SLOTS:
            void areaEntered(const
    **QGeoAreaMonitorInfo**  &mon, const **QGeoPositionInfo**  &update)
    {
                Q_UNUSED(mon);

                **qDebug** () << "Now within
    100 meters, current position is" << update.coordinate();
            }
    void areaExited(const **QGeoAreaMonitorInfo**  &mon, const
    **QGeoPositionInfo**  &update)
            {
                Q_UNUSED(mon);
    **qDebug** () << "No longer within 100 meters, current position is" <<
    update.coordinate();
            }

    `QGeoAreaMonitorSource` follows a singleton pattern. Each instance of the
    class with the same **sourceName** () shares the same area monitoring
    backend. If a new **QGeoAreaMonitorInfo**  object is added via
    **startMonitoring** () or **requestUpdate** () it can be retrieved by
    another instance of this class (provided that they are sourced from the same
    area monitor provider plug-in). The same singleton pattern applies to the
    **QGeoPositionInfoSource**  instance used by this class. The following code
    snippet emphasizes the behavior:

    **QGeoAreaMonitorSource**  *s1 = **QGeoAreaMonitorSource**
    ::createSource("blah", this);
        **QGeoAreaMonitorSource**  *s2 =
    **QGeoAreaMonitorSource** ::createSource("blah", this);
    QVERIFY(s1->positionInfoSource() == s2->positionInfoSource);
    """

    class AreaMonitorFeature(enum.Flag):
        PersistentAreaMonitorFeature: QGeoAreaMonitorSource = ...
        AnyAreaMonitorFeature: QGeoAreaMonitorSource = ...

    class Error(enum.Enum):
        AccessError: QGeoAreaMonitorSource = ...
        InsufficientPositionInfo: QGeoAreaMonitorSource = ...
        UnknownSourceError: QGeoAreaMonitorSource = ...
        NoError: QGeoAreaMonitorSource = ...

    def __init__(self, parent: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#QGeoAreaMonitorSource

        **QGeoAreaMonitorSource::QGeoAreaMonitorSource(QObject * parent )**

        Creates a monitor source with the given **parent**.
        """
        ...

    def backendProperty(self, name: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#backendProperty

        **[virtual, since 6.2] QVariant
        QGeoAreaMonitorSource::backendProperty(const QString & name ) const**

        Returns the value of the backend-specific property named **name** , if
        present. Otherwise the returned value will be invalid.

        This function was introduced in Qt 6.2.

        **See also** **setBackendProperty** ().
        """
        ...

    def setBackendProperty(self, name: str, value: typing.Any) -> bool:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#setBackendProperty

        **[virtual, since 6.2] bool
        QGeoAreaMonitorSource::setBackendProperty(const QString & name , const
        QVariant & value )**

        Sets the backend-specific property named **name** to **value**. Returns
        `true` on success, otherwise returns `false`. Backend-specific
        properties can be used to configure the area monitoring subsystem
        behavior at runtime.

        This function was introduced in Qt 6.2.

        **See also** **backendProperty** ().
        """
        ...

    @typing.overload
    def activeMonitors(self) -> typing.List[QGeoAreaMonitorInfo]:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#activeMonitors

        **[pure virtual] QList<QGeoAreaMonitorInfo>
        QGeoAreaMonitorSource::activeMonitors() const**

        Returns the list of all active monitors known to the
        **QGeoAreaMonitorSource**  object.

        An active monitor was started via **startMonitoring** (). For every
        active monitor the source object will emit the required signals, such as
        **areaEntered** () or **areaExited** (). Multiple
        **QGeoAreaMonitorSource**  instances within the same application share
        the same active monitor objects.

        Unless an active **QGeoAreaMonitorInfo**  **isPersistent** () an active
        **QGeoAreaMonitorInfo**  will be stopped once the current application
        terminates.
        """
        ...

    @typing.overload
    def activeMonitors(
        self, lookupArea: "QGeoShape"
    ) -> typing.List[QGeoAreaMonitorInfo]:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#activeMonitors-1

        **[pure virtual] QList<QGeoAreaMonitorInfo>
        QGeoAreaMonitorSource::activeMonitors(const QGeoShape & lookupArea )
        const**

        Returns the list of all active monitors known to the
        **QGeoAreaMonitorSource**  object whose center lies within
        **lookupArea**. If **lookupArea** is empty the returned list will be
        empty.

        An active monitor was started via **startMonitoring** (). For every
        active monitor the source object will emit the required signals, such as
        **areaEntered** () or **areaExited** (). Multiple
        **QGeoAreaMonitorSource**  instances within the same application share
        the same active monitor objects.

        Unless an active **QGeoAreaMonitorInfo**  **isPersistent** () an active
        **QGeoAreaMonitorInfo**  will be stopped once the current application
        terminates.

        **See also** **QGeoShape** .
        """
        ...

    def requestUpdate(self, monitor: QGeoAreaMonitorInfo, signal: str) -> bool:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#requestUpdate

        **[pure virtual] bool QGeoAreaMonitorSource::requestUpdate(const
        QGeoAreaMonitorInfo & monitor , const char * signal )**

        Enables single shot area monitoring. Area monitoring for **monitor**
        will be performed until this **QGeoAreaMonitorSource**  instance emits
        **signal** for the first time. Once the signal was emitted, **monitor**
        is automatically removed from the list of **activeMonitors** (). If
        **monitor** is invalid or has an expiry date that has been passed, this
        function returns `false`.

        QGeoAreaMonitor singleShotMonitor;
            **QGeoAreaMonitorSource**  *
        source = **QGeoAreaMonitorSource** ::createDefaultSource(this);
        //...
            bool ret = source->requestUpdate(singleShotMonitor,
        SIGNAL(areaExited(QGeoAreaMonitor,**QGeoPositionInfo** )));

        The above `singleShotMonitor` object will cease to send updates once the
        **areaExited** () signal was emitted for the first time. Until this
        point in time any other signal may be emitted zero or more times
        depending on the area context.

        It is not possible to simultanously request updates for more than one
        signal of the same monitor object. The last call to this function
        determines the signal upon which the updates cease to continue. At this
        stage only the **areaEntered** () and **areaExited** () signals can be
        used to terminate the monitoring process.

        Requesting persistent monitoring on a **QGeoAreaMonitorSource**
        instance fails if the area monitoring backend doesn't support
        **QGeoAreaMonitorSource::PersistentAreaMonitorFeature** .

        If **monitor** was already registered via **startMonitoring** () it is
        converted to a single shot behavior.

        **Note:** Since Qt6 this method always resets the last error to
        **NoError**  before starting monitoring.

        **See also** **startMonitoring** () and **stopMonitoring** ().
        """
        ...

    def stopMonitoring(self, monitor: QGeoAreaMonitorInfo) -> bool:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#stopMonitoring

        **[pure virtual] bool QGeoAreaMonitorSource::stopMonitoring(const
        QGeoAreaMonitorInfo & monitor )**

        Returns true if **monitor** was successfully removed from the list of
        **activeMonitors** (); otherwise returns false. This behavior is
        independent on whether **monitor** was registered via
        **startMonitoring** () or **requestUpdate** ().
        """
        ...

    def startMonitoring(self, monitor: QGeoAreaMonitorInfo) -> bool:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#startMonitoring

        **[pure virtual] bool QGeoAreaMonitorSource::startMonitoring(const
        QGeoAreaMonitorInfo & monitor )**

        Returns `true` if the monitoring of **monitor** could be successfully
        started; otherwise returns `false`. A reason for not being able to start
        monitoring could be the unavailability of an appropriate default
        position info source while no alternative **QGeoPositionInfoSource**
        has been set via **setPositionInfoSource** ().

        If **monitor** is already active, the existing monitor object will be
        replaced by the new **monitor** reference. The identification of
        **QGeoAreaMonitorInfo**  instances happens via
        **QGeoAreaMonitorInfo::identifier** (). Therefore this function can also
        be used to update active monitors.

        If **monitor** has an expiry date that has been passed this function
        returns false. Calling this function for an already via
        **requestUpdate** () registered single shot monitor switches the monitor
        to a permanent monitoring mode.

        Requesting persistent monitoring on a **QGeoAreaMonitorSource**
        instance fails if the area monitoring backend doesn't support
        **QGeoAreaMonitorSource::PersistentAreaMonitorFeature** .

        **Note:** Since Qt6 this method always resets the last error to
        **NoError**  before starting monitoring.

        **See also** **stopMonitoring** ().
        """
        ...

    def supportedAreaMonitorFeatures(
        self,
    ) -> "QGeoAreaMonitorSource.AreaMonitorFeature":
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#supportedAreaMonitorFe
        atures

        **[pure virtual] QGeoAreaMonitorSource::AreaMonitorFeatures
        QGeoAreaMonitorSource::supportedAreaMonitorFeatures() const**

        Returns the area monitoring features available to this source.
        """
        ...

    def error(self) -> "QGeoAreaMonitorSource.Error":
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#error

        **[pure virtual] QGeoAreaMonitorSource::Error
        QGeoAreaMonitorSource::error() const**

        Returns the type of error that last occurred.

        **Note:** Since Qt6 the last error is always reset when calling
        **startMonitoring** () or **requestUpdate** ().
        """
        ...

    def sourceName(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#sourceName

        **QString QGeoAreaMonitorSource::sourceName() const**

        Returns the unique name of the area monitor source implementation in
        use.

        This is the same name that can be passed to **createSource** () in order
        to create a new instance of a particular area monitor source
        implementation.
        """
        ...

    def positionInfoSource(self) -> "QGeoPositionInfoSource":
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#positionInfoSource

        **[virtual] QGeoPositionInfoSource
        *QGeoAreaMonitorSource::positionInfoSource() const**

        Returns the current **QGeoPositionInfoSource**  used by this
        **QGeoAreaMonitorSource**  object. The function will return
        **QGeoPositionInfoSource::createDefaultSource** () if no other object
        has been set.

        The function returns `nullptr` if not even a default
        **QGeoPositionInfoSource**  exists.

        Any usage of the returned **QGeoPositionInfoSource**  instance should
        account for the fact that it may reside in a different thread.

        **See also** **QGeoPositionInfoSource**  and **setPositionInfoSource**
        ().
        """
        ...

    def setPositionInfoSource(self, source: "QGeoPositionInfoSource") -> None:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#setPositionInfoSource

        **[virtual] void
        QGeoAreaMonitorSource::setPositionInfoSource(QGeoPositionInfoSource *
        newSource )**

        Sets the new **QGeoPositionInfoSource**  to be used by this
        **QGeoAreaMonitorSource**  object. The area monitoring backend becomes
        the new **QObject**  parent for **newSource**. The previous
        **QGeoPositionInfoSource**  object will be deleted. All
        **QGeoAreaMonitorSource**  instances based on the same **sourceName** ()
        share the same **QGeoPositionInfoSource**  instance.

        This may be useful when it is desirable to manipulate the positioning
        system used by the area monitoring engine.

        Note that ownership must be taken care of by subclasses of
        **QGeoAreaMonitorSource** . Due to the singleton pattern behind this
        class **newSource** may be moved to a new thread.

        **See also** **positionInfoSource** ().
        """
        ...

    @staticmethod
    def availableSources() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#availableSources

        **[static] QStringList QGeoAreaMonitorSource::availableSources()**

        Returns a list of available monitor plugins, including the default
        system backend if one is available.
        """
        ...

    @staticmethod
    def createSource(
        sourceName: str, parent: QtCore.QObject
    ) -> "QGeoAreaMonitorSource":
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#createSource

        **[static] QGeoAreaMonitorSource
        *QGeoAreaMonitorSource::createSource(const QString & sourceName ,
        QObject * parent )**

        Creates and returns a monitor source with the given **parent** , by
        loading the plugin named **sourceName**.

        Returns `nullptr` if the plugin cannot be found.
        """
        ...

    @staticmethod
    def createDefaultSource(parent: QtCore.QObject) -> "QGeoAreaMonitorSource":
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#createDefaultSource

        **[static] QGeoAreaMonitorSource
        *QGeoAreaMonitorSource::createDefaultSource(QObject * parent )**

        Creates and returns a monitor source with the given **parent** that
        monitors areas using resources on the underlying system.

        Returns `nullptr` if the system has no support for position monitoring.
        """
        ...

    @property
    def areaEntered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#areaEntered

        **[signal] void QGeoAreaMonitorSource::areaEntered(const
        QGeoAreaMonitorInfo & monitor , const QGeoPositionInfo & update )**

        Emitted when the current position has moved from a position outside of
        the active **monitor** to a position within the monitored area.

        The **update** holds the new position.
        """
        ...

    @property
    def areaExited(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#areaExited

        **[signal] void QGeoAreaMonitorSource::areaExited(const
        QGeoAreaMonitorInfo & monitor , const QGeoPositionInfo & update )**

        Emitted when the current position has moved from a position within the
        active **monitor** to a position outside the monitored area.

        The **update** holds the new position.
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#errorOccurred

        **[signal] void
        QGeoAreaMonitorSource::errorOccurred(QGeoAreaMonitorSource::Error
        areaMonitoringError )**

        This signal is emitted after an error occurred. The
        **areaMonitoringError** parameter describes the type of error that
        occurred.
        """
        ...

    @property
    def monitorExpired(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorsource.html#monitorExpired

        **[signal] void QGeoAreaMonitorSource::monitorExpired(const
        QGeoAreaMonitorInfo & monitor )**

        Emitted when **monitor** has expired. An expired area monitor is
        automatically removed from the list of **activeMonitors** ().

        **See also** **activeMonitors** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QStringListModel(QAbstractListModel):
    """
    https://doc.qt.io/qt-6/qstringlistmodel.html

    **Detailed Description**

    QStringListModel is an editable model that can be used for simple cases
    where you need to display a number of strings in a view widget, such as a
    **QListView**  or a **QComboBox** .

    The model provides all the standard functions of an editable model,
    representing the data in the string list as a model with one column and a
    number of rows equal to the number of items in the list.

    Model indexes corresponding to items are obtained with the **index** ()
    function, and item flags are obtained with **flags** (). Item data is read
    with the **data** () function and written with **setData** (). The number of
    rows (and number of items in the string list) can be found with the
    **rowCount** () function.

    The model can be constructed with an existing string list, or strings can be
    set later with the **setStringList** () convenience function. Strings can
    also be inserted in the usual way with the **insertRows** () function, and
    removed with **removeRows** (). The contents of the string list can be
    retrieved with the **stringList** () convenience function.

    An example usage of QStringListModel:

    **QStringListModel**  *model = new **QStringListModel** ();
    **QStringList**  list;
            list << "a" << "b" << "c";
    model->setStringList(list);

    **See also** **QAbstractListModel** , **QAbstractItemModel** , and **Model
    Classes** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#QStringListModel

        **QStringListModel::QStringListModel(QObject * parent = nullptr)**

        Constructs a string list model with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, strings: typing.Iterable[str], parent: typing.Optional[QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#QStringListModel-1

        **QStringListModel::QStringListModel(const QStringList & strings ,
        QObject * parent = nullptr)**

        Constructs a string list model containing the specified **strings** with
        the given **parent**.
        """
        ...

    def clearItemData(self, index: QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#clearItemData

        **[override virtual, since 6.0] bool
        QStringListModel::clearItemData(const QModelIndex & index )**

        Reimplements: **QAbstractItemModel::clearItemData** (const QModelIndex
        &index).

        This function was introduced in Qt 6.0.
        """
        ...

    def setItemData(
        self, index: QModelIndex, roles: typing.Dict[int, typing.Any]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#setItemData

        **[override virtual, since 5.13] bool
        QStringListModel::setItemData(const QModelIndex & index , const
        QMap<int, QVariant> & roles )**

        Reimplements: **QAbstractItemModel::setItemData** (const QModelIndex
        &index, const QMap<int, QVariant> &roles).

        If **roles** contains both **Qt::DisplayRole**  and **Qt::EditRole** ,
        the latter will take precedence

        This function was introduced in Qt 5.13.

        **See also** **itemData** ().
        """
        ...

    def itemData(self, index: QModelIndex) -> typing.Dict[int, typing.Any]:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#itemData

        **[override virtual, since 5.13] QMap<int, QVariant>
        QStringListModel::itemData(const QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::itemData(const QModelIndex &index)
        const** .

        This function was introduced in Qt 5.13.

        **See also** **setItemData** ().
        """
        ...

    def moveRows(
        self,
        sourceParent: QModelIndex,
        sourceRow: int,
        count: int,
        destinationParent: QModelIndex,
        destinationChild: int,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#moveRows

        **[override virtual, since 5.13] bool QStringListModel::moveRows(const
        QModelIndex & sourceParent , int sourceRow , int count , const
        QModelIndex & destinationParent , int destinationChild )**

        Reimplements: **QAbstractItemModel::moveRows** (const QModelIndex
        &sourceParent, int sourceRow, int count, const QModelIndex
        &destinationParent, int destinationChild).

        This function was introduced in Qt 5.13.
        """
        ...

    def sibling(self, row: int, column: int, idx: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#sibling

        **[override virtual] QModelIndex QStringListModel::sibling(int row , int
        column , const QModelIndex & idx ) const**

        Reimplements: **QAbstractListModel::sibling(int row, int column, const
        QModelIndex &idx) const** .
        """
        ...

    def supportedDropActions(self) -> Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#supportedDropActions

        **[override virtual] Qt::DropActions
        QStringListModel::supportedDropActions() const**

        Reimplements: **QAbstractItemModel::supportedDropActions() const** .
        """
        ...

    def sort(self, column: int, order: Qt.SortOrder = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#sort

        **[override virtual] void QStringListModel::sort(int column ,
        Qt::SortOrder order = Qt::AscendingOrder)**

        Reimplements: **QAbstractItemModel::sort** (int column, Qt::SortOrder
        order).
        """
        ...

    def setStringList(self, strings: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#setStringList

        **void QStringListModel::setStringList(const QStringList & strings )**

        Sets the model's internal string list to **strings**. The model will
        notify any attached views that its underlying data has changed.

        **See also** **stringList** () and **dataChanged** ().
        """
        ...

    def stringList(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#stringList

        **QStringList QStringListModel::stringList() const**

        Returns the string list used by the model to store data.

        **See also** **setStringList** ().
        """
        ...

    def removeRows(self, row: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#removeRows

        **[override virtual] bool QStringListModel::removeRows(int row , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeRows** (int row, int count,
        const QModelIndex &parent).

        Removes **count** rows from the model, beginning at the given **row**.

        The **parent** index of the rows is optional and is only used for
        consistency with **QAbstractItemModel** . By default, a null index is
        specified, indicating that the rows are removed in the top level of the
        model.

        Returns `true` if the row removal was successful.

        **See also** **QAbstractItemModel::removeRows** ().
        """
        ...

    def insertRows(self, row: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#insertRows

        **[override virtual] bool QStringListModel::insertRows(int row , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertRows** (int row, int count,
        const QModelIndex &parent).

        Inserts **count** rows into the model, beginning at the given **row**.

        The **parent** index of the rows is optional and is only used for
        consistency with **QAbstractItemModel** . By default, a null index is
        specified, indicating that the rows are inserted in the top level of the
        model.

        Returns `true` if the insertion was successful.

        **See also** **QAbstractItemModel::insertRows** ().
        """
        ...

    def flags(self, index: QModelIndex) -> Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#flags

        **[override virtual] Qt::ItemFlags QStringListModel::flags(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractListModel::flags(const QModelIndex &index)
        const** .

        Returns the flags for the item with the given **index**.

        Valid items are enabled, selectable, editable, drag enabled and drop
        enabled.

        **See also** **QAbstractItemModel::flags** ().
        """
        ...

    def setData(self, index: QModelIndex, value: typing.Any, role: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#setData

        **[override virtual] bool QStringListModel::setData(const QModelIndex &
        index , const QVariant & value , int role = Qt::EditRole)**

        Reimplements: **QAbstractItemModel::setData** (const QModelIndex &index,
        const QVariant &value, int role).

        Sets the data for the specified **role** in the item with the given
        **index** in the model, to the provided **value**.

        The **dataChanged** () signal is emitted if the item is changed. Returns
        `true` after emitting the **dataChanged** () signal.

        **See also** **Qt::ItemDataRole**  and **data** ().
        """
        ...

    def data(self, index: QModelIndex, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#data

        **[override virtual] QVariant QStringListModel::data(const QModelIndex &
        index , int role = Qt::DisplayRole) const**

        Reimplements: **QAbstractItemModel::data(const QModelIndex &index, int
        role) const** .

        Returns data for the specified **role** , from the item with the given
        **index**.

        If the view requests an invalid index, an invalid variant is returned.

        **See also** **setData** ().
        """
        ...

    def rowCount(self, parent: QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qstringlistmodel.html#rowCount

        **[override virtual] int QStringListModel::rowCount(const QModelIndex &
        parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::rowCount(const QModelIndex &parent)
        const** .

        Returns the number of rows in the model. This value corresponds to the
        number of items in the model's internal string list.

        The optional **parent** argument is in most models used to specify the
        parent of the rows to be counted. Because this is a list if a valid
        parent is specified, the result will always be 0.

        **See also** **insertRows** (), **removeRows** (), and
        **QAbstractItemModel::rowCount** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QBluetoothAddress(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qbluetoothaddress.html

    **Detailed Description**

    This class holds a Bluetooth address in a platform- and protocol-independent
    manner.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothaddress.html#QBluetoothAddress

        **QBluetoothAddress::QBluetoothAddress()**

        Constructs an null Bluetooth Address.
        """
        ...

    @typing.overload
    def __init__(self, address: int) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothaddress.html#QBluetoothAddress-1

        **QBluetoothAddress::QBluetoothAddress(quint64 address )**

        Constructs a new Bluetooth address and assigns **address** to it.
        """
        ...

    @typing.overload
    def __init__(self, address: str) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothaddress.html#QBluetoothAddress-2

        **QBluetoothAddress::QBluetoothAddress(const QString & address )**

        Constructs a new Bluetooth address and assigns **address** to it.

        The format of **address** can be either XX:XX:XX:XX:XX:XX or
        XXXXXXXXXXXX, where X is a hexadecimal digit. Case is not important.
        """
        ...

    @typing.overload
    def __init__(self, other: "QBluetoothAddress") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothaddress.html#QBluetoothAddress-3

        **QBluetoothAddress::QBluetoothAddress(const QBluetoothAddress & other
        )**

        Constructs a new Bluetooth address which is a copy of **other**.
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothaddress.html#toString

        **QString QBluetoothAddress::toString() const**

        Returns the Bluetooth address as a string of the form,
        XX:XX:XX:XX:XX:XX.
        """
        ...

    def toUInt64(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothaddress.html#toUInt64

        **quint64 QBluetoothAddress::toUInt64() const**

        Returns this Bluetooth address as a quint64.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothaddress.html#clear

        **void QBluetoothAddress::clear()**

        Sets the Bluetooth address to 00:00:00:00:00:00.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothaddress.html#isNull

        **bool QBluetoothAddress::isNull() const**

        Returns true if the Bluetooth address is null, otherwise returns false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtNetwork
from PyQt6 import QtCore
from PyQt6.QtWebSockets import *
import enum


class QWebSocketServer(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qwebsocketserver.html

    **Detailed Description**

    It is modeled after **QTcpServer** , and behaves the same. So, if you know
    how to use **QTcpServer** , you know how to use QWebSocketServer. This class
    makes it possible to accept incoming WebSocket connections. You can specify
    the port or have QWebSocketServer pick one automatically. You can listen on
    a specific address or on all the machine's addresses. Call **listen** () to
    have the server listen for incoming connections.

    The **newConnection** () signal is then emitted each time a client connects
    to the server. Call **nextPendingConnection** () to accept the pending
    connection as a connected **QWebSocket** . The function returns a pointer to
    a **QWebSocket**  in **QAbstractSocket::ConnectedState**  that you can use
    for communicating with the client.

    If an error occurs, **serverError** () returns the type of error, and
    **errorString** () can be called to get a human readable description of what
    happened.

    When listening for connections, the address and port on which the server is
    listening are available as **serverAddress** () and **serverPort** ().

    Calling **close** () makes QWebSocketServer stop listening for incoming
    connections.

    QWebSocketServer currently does not support **WebSocket Extensions**  and
    **WebSocket Subprotocols** .

    **Note:** When working with self-signed certificates, **Firefox bug 594502**
    prevents **Firefox**  to connect to a secure WebSocket server. To work
    around this problem, first browse to the secure WebSocket server using
    HTTPS. FireFox will indicate that the certificate is invalid. From here on,
    the certificate can be added to the exceptions. After this, the secure
    WebSockets connection should work.

    QWebSocketServer only supports version 13 of the WebSocket protocol, as
    outlined in **RFC 6455** .

    There is a default connection handshake timeout of 10 seconds to avoid
    denial of service, which can be customized using **setHandshakeTimeout** ().

    **See also** **WebSocket Server Example**  and **QWebSocket** .
    """

    class SslMode(enum.Enum):
        SecureMode: QWebSocketServer = ...
        NonSecureMode: QWebSocketServer = ...

    def __init__(
        self,
        serverName: str,
        secureMode: "QWebSocketServer.SslMode",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#QWebSocketServer-1

        **QWebSocketServer::QWebSocketServer(const QString & serverName ,
        QWebSocketServer::SslMode secureMode , QObject * parent = nullptr)**

        Constructs a new QWebSocketServer with the given **serverName**. The
        **serverName** will be used in the HTTP handshake phase to identify the
        server. It can be empty, in which case no server name will be sent to
        the client. The **secureMode** parameter indicates whether the server
        operates over wss (**SecureMode** ) or over ws (**NonSecureMode** ).

        **parent** is passed to the **QObject**  constructor.
        """
        ...

    def handshakeTimeoutMS(self) -> int:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#handshakeTimeoutMS

        **[since 5.14] int QWebSocketServer::handshakeTimeoutMS() const**

        Returns the handshake timeout for new connections in milliseconds.

        The default is 10 seconds. If a peer uses more time to complete the
        handshake their connection is closed.

        This function was introduced in Qt 5.14.

        **See also** **setHandshakeTimeout** () and **handshakeTimeout** ().
        """
        ...

    def setHandshakeTimeout(self, msec: int) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#setHandshakeTimeout

        **[since 5.14] void
        QWebSocketServer::setHandshakeTimeout(std::chrono::milliseconds msec )**

        Sets the handshake timeout for new connections to **msec** milliseconds.

        By default this is set to 10 seconds. If a peer uses more time to
        complete the handshake, their connection is closed. You can pass a
        negative value (e.g. -1) to disable the timeout.

        This function was introduced in Qt 5.14.

        **See also** **handshakeTimeout** () and **handshakeTimeoutMS** ().
        """
        ...

    def handleConnection(self, socket: QtNetwork.QTcpSocket) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#handleConnection

        **[since 5.9] void QWebSocketServer::handleConnection(QTcpSocket *
        socket ) const**

        Upgrades a tcp **socket** to websocket.

        The **QWebSocketServer**  object will take ownership of the socket
        object and delete it when appropriate.

        This function was introduced in Qt 5.9.
        """
        ...

    def serverUrl(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#serverUrl

        **QUrl QWebSocketServer::serverUrl() const**

        Returns a URL clients can use to connect to this server if the server is
        listening for connections. Otherwise an invalid URL is returned.

        **See also** **serverPort** (), **serverAddress** (), and **listen** ().
        """
        ...

    def supportedVersions(self) -> typing.List[QWebSocketProtocol.Version]:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#supportedVersions

        **QList<QWebSocketProtocol::Version>
        QWebSocketServer::supportedVersions() const**

        Returns a list of WebSocket versions that this server is supporting.
        """
        ...

    def sslConfiguration(self) -> QtNetwork.QSslConfiguration:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#sslConfiguration

        **QSslConfiguration QWebSocketServer::sslConfiguration() const**

        Returns the SSL configuration used by the **QWebSocketServer** . If the
        server is not running in secure mode (**QWebSocketServer::SecureMode**
        ), this method returns **QSslConfiguration::defaultConfiguration** ().

        **See also** **setSslConfiguration** (), **SslMode** , and
        **QSslConfiguration::defaultConfiguration** ().
        """
        ...

    def setSslConfiguration(
        self, sslConfiguration: QtNetwork.QSslConfiguration
    ) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#setSslConfiguration

        **void QWebSocketServer::setSslConfiguration(const QSslConfiguration &
        sslConfiguration )**

        Sets the SSL configuration for the **QWebSocketServer**  to
        **sslConfiguration**. This method has no effect if **QWebSocketServer**
        runs in non-secure mode (**QWebSocketServer::NonSecureMode** ).

        **See also** **sslConfiguration** () and **SslMode** .
        """
        ...

    def proxy(self) -> QtNetwork.QNetworkProxy:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#proxy

        **QNetworkProxy QWebSocketServer::proxy() const**

        Returns the network proxy for this server. By default
        **QNetworkProxy::DefaultProxy**  is used.

        **See also** **setProxy** ().
        """
        ...

    def setProxy(self, networkProxy: QtNetwork.QNetworkProxy) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#setProxy

        **void QWebSocketServer::setProxy(const QNetworkProxy & networkProxy )**

        Sets the explicit network proxy for this server to **networkProxy**.

        To disable the use of a proxy, use the **QNetworkProxy::NoProxy**  proxy
        type:

        server->setProxy(**QNetworkProxy** ::NoProxy);

        **See also** **proxy** ().
        """
        ...

    def serverName(self) -> str:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#serverName

        **QString QWebSocketServer::serverName() const**

        Returns the server name that is used during the http handshake phase.

        **See also** **setServerName** ().
        """
        ...

    def setServerName(self, serverName: str) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#setServerName

        **void QWebSocketServer::setServerName(const QString & serverName )**

        Sets the server name that will be used during the HTTP handshake phase
        to the given **serverName**. The **serverName** can be empty, in which
        case an empty server name will be sent to the client. Existing connected
        clients will not be notified of this change, only newly connecting
        clients will see this new name.

        **See also** **serverName** ().
        """
        ...

    def resumeAccepting(self) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#resumeAccepting

        **void QWebSocketServer::resumeAccepting()**

        Resumes accepting new connections.

        **See also** **pauseAccepting** ().
        """
        ...

    def pauseAccepting(self) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#pauseAccepting

        **void QWebSocketServer::pauseAccepting()**

        Pauses incoming new connections. Queued connections will remain in
        queue.

        **See also** **resumeAccepting** ().
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#errorString

        **QString QWebSocketServer::errorString() const**

        Returns a human readable description of the last error that occurred. If
        no error occurred, an empty string is returned.

        **See also** **serverError** ().
        """
        ...

    def error(self) -> QWebSocketProtocol.CloseCode:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#error

        **QWebSocketProtocol::CloseCode QWebSocketServer::error() const**

        Returns an error code for the last error that occurred. If no error
        occurred, **QWebSocketProtocol::CloseCodeNormal**  is returned.

        **See also** **errorString** ().
        """
        ...

    def nextPendingConnection(self) -> QWebSocket:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#nextPendingConnection

        **[virtual] QWebSocket *QWebSocketServer::nextPendingConnection()**

        Returns the next pending connection as a connected **QWebSocket**
        object. **QWebSocketServer**  does not take ownership of the returned
        **QWebSocket**  object. It is up to the caller to delete the object
        explicitly when it will no longer be used, otherwise a memory leak will
        occur. nullptr is returned if this function is called when there are no
        pending connections.

        Note: The returned **QWebSocket**  object cannot be used from another
        thread.

        **See also** **hasPendingConnections** ().
        """
        ...

    def hasPendingConnections(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#hasPendingConnections

        **bool QWebSocketServer::hasPendingConnections() const**

        Returns true if the server has pending connections; otherwise returns
        false.

        **See also** **nextPendingConnection** () and
        **setMaxPendingConnections** ().
        """
        ...

    def socketDescriptor(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#socketDescriptor

        **[since 5.3] qintptr QWebSocketServer::socketDescriptor() const**

        Returns the native socket descriptor the server uses to listen for
        incoming instructions, or -1 if the server is not listening. If the
        server is using **QNetworkProxy** , the returned descriptor may not be
        usable with native socket functions.

        This function was introduced in Qt 5.3.

        **See also** **setSocketDescriptor** () and **isListening** ().
        """
        ...

    def setSocketDescriptor(self, socketDescriptor: PyQt6.sip.voidptr) -> bool:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#setSocketDescriptor

        **[since 5.3] bool QWebSocketServer::setSocketDescriptor(qintptr
        socketDescriptor )**

        Sets the socket descriptor this server should use when listening for
        incoming connections to **socketDescriptor**.

        Returns true if the socket is set successfully; otherwise returns false.
        The socket is assumed to be in listening state.

        This function was introduced in Qt 5.3.

        **See also** **socketDescriptor** () and **isListening** ().
        """
        ...

    def secureMode(self) -> "QWebSocketServer.SslMode":
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#secureMode

        **QWebSocketServer::SslMode QWebSocketServer::secureMode() const**

        Returns the secure mode the server is running in.

        **See also** **QWebSocketServer** () and **SslMode** .
        """
        ...

    def serverAddress(self) -> QtNetwork.QHostAddress:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#serverAddress

        **QHostAddress QWebSocketServer::serverAddress() const**

        Returns the server's address if the server is listening for connections;
        otherwise returns **QHostAddress::Null** .

        **See also** **serverPort** () and **listen** ().
        """
        ...

    def serverPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#serverPort

        **quint16 QWebSocketServer::serverPort() const**

        Returns the server's port if the server is listening for connections;
        otherwise returns 0.

        **See also** **serverAddress** () and **listen** ().
        """
        ...

    def maxPendingConnections(self) -> int:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#maxPendingConnections

        **int QWebSocketServer::maxPendingConnections() const**

        Returns the maximum number of pending accepted connections. The default
        is 30.

        **See also** **setMaxPendingConnections** () and
        **hasPendingConnections** ().
        """
        ...

    def setMaxPendingConnections(self, numConnections: int) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#setMaxPendingConnections

        **void QWebSocketServer::setMaxPendingConnections(int numConnections )**

        Sets the maximum number of pending accepted connections to
        **numConnections**. **WebSocketServer**  will accept no more than
        **numConnections** incoming connections before **nextPendingConnection**
        () is called. By default, the limit is 30 pending connections.

        **QWebSocketServer**  will emit the **error** () signal with the
        **QWebSocketProtocol::CloseCodeAbnormalDisconnection**  close code when
        the maximum of connections has been reached. The WebSocket handshake
        will fail and the socket will be closed.

        **See also** **maxPendingConnections** () and **hasPendingConnections**
        ().
        """
        ...

    def isListening(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#isListening

        **bool QWebSocketServer::isListening() const**

        Returns true if the server is currently listening for incoming
        connections; otherwise returns false. If listening fails, **error** ()
        will return the reason.

        **See also** **listen** () and **error** ().
        """
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#close

        **void QWebSocketServer::close()**

        Closes the server. The server will no longer listen for incoming
        connections.
        """
        ...

    def listen(
        self,
        address: typing.Union[
            QtNetwork.QHostAddress, QtNetwork.QHostAddress.SpecialAddress
        ] = ...,
        port: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#listen

        **bool QWebSocketServer::listen(const QHostAddress & address =
        QHostAddress::Any, quint16 port = 0)**

        Tells the server to listen for incoming connections on address
        **address** and port **port**. If **port** is 0, a port is chosen
        automatically. If **address** is **QHostAddress::Any** , the server will
        listen on all network interfaces.

        Returns true on success; otherwise returns false.

        **See also** **isListening** ().
        """
        ...

    @property
    def acceptError(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#acceptError

        **[signal] void
        QWebSocketServer::acceptError(QAbstractSocket::SocketError socketError
        )**

        This signal is emitted when the acceptance of a new connection results
        in an error. The **socketError** parameter describes the type of error
        that occurred.

        **See also** **pauseAccepting** () and **resumeAccepting** ().
        """
        ...

    @property
    def alertReceived(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#alertReceived

        **[signal, since 6.2] void
        QWebSocketServer::alertReceived(QSsl::AlertLevel level , QSsl::AlertType
        type , const QString & description )**

        **QWebSocketServer**  emits this signal if an alert message was received
        from a peer. **level** tells if the alert was fatal or it was a warning.
        **type** is the code explaining why the alert was sent. When a textual
        description of the alert message is available, it is supplied in
        **description**.

        **Note:** The signal is mostly for informational and debugging purposes
        and does not require any handling in the application. If the alert was
        fatal, underlying backend will handle it and close the connection.

        **Note:** Not all backends support this functionality.

        This function was introduced in Qt 6.2.

        **See also** **alertSent** (), **QSsl::AlertLevel** , and
        **QSsl::AlertType** .
        """
        ...

    @property
    def alertSent(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#alertSent

        **[signal, since 6.2] void QWebSocketServer::alertSent(QSsl::AlertLevel
        level , QSsl::AlertType type , const QString & description )**

        **QWebSocketServer**  emits this signal if an alert message was sent to
        a peer. **level** describes if it was a warning or a fatal error.
        **type** gives the code of the alert message. When a textual description
        of the alert message is available, it is supplied in **description**.

        **Note:** This signal is mostly informational and can be used for
        debugging purposes, normally it does not require any actions from the
        application.

        **Note:** Not all backends support this functionality.

        This function was introduced in Qt 6.2.

        **See also** **alertReceived** (), **QSsl::AlertLevel** , and
        **QSsl::AlertType** .
        """
        ...

    @property
    def closed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#closed

        **[signal] void QWebSocketServer::closed()**

        This signal is emitted when the server closed its connection.

        **See also** **close** ().
        """
        ...

    @property
    def handshakeInterruptedOnError(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#handshakeInterruptedOnError

        **[signal, since 6.2] void
        QWebSocketServer::handshakeInterruptedOnError(const QSslError & error
        )**

        **QWebSocketServer**  emits this signal if a certificate verification
        **error** was found and if early error reporting was enabled in
        **QSslConfiguration** .

        This function was introduced in Qt 6.2.

        **See also** **sslErrors** () and
        **QSslConfiguration::setHandshakeMustInterruptOnError** ().
        """
        ...

    @property
    def newConnection(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#newConnection

        **[signal] void QWebSocketServer::newConnection()**

        This signal is emitted every time a new connection is available.

        **See also** **hasPendingConnections** () and **nextPendingConnection**
        ().
        """
        ...

    @property
    def originAuthenticationRequired(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#originAuthenticationRequire
        d

        **[signal] void QWebSocketServer::originAuthenticationRequired(QWebSocke
        tCorsAuthenticator * authenticator )**

        This signal is emitted when a new connection is requested. The slot
        connected to this signal should indicate whether the origin (which can
        be determined by the origin() call) is allowed in the **authenticator**
        object (by issuing **setAllowed** ()).

        If no slot is connected to this signal, all origins will be accepted by
        default.

        **Note:** It is not possible to use a QueuedConnection to connect to
        this signal, as the connection will always succeed.
        """
        ...

    @property
    def peerVerifyError(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#peerVerifyError

        **[signal] void QWebSocketServer::peerVerifyError(const QSslError &
        error )**

        **QWebSocketServer**  can emit this signal several times during the SSL
        handshake, before encryption has been established, to indicate that an
        error has occurred while establishing the identity of the peer. The
        **error** is usually an indication that **QWebSocketServer**  is unable
        to securely identify the peer.

        This signal provides you with an early indication when something is
        wrong. By connecting to this signal, you can manually choose to tear
        down the connection from inside the connected slot before the handshake
        has completed. If no action is taken, **QWebSocketServer**  will proceed
        to emitting **QWebSocketServer::sslErrors** ().

        **See also** **sslErrors** ().
        """
        ...

    @property
    def preSharedKeyAuthenticationRequired(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#preSharedKeyAuthenticationR
        equired

        **[signal, since 5.8] void QWebSocketServer::preSharedKeyAuthenticationR
        equired(QSslPreSharedKeyAuthenticator * authenticator )**

        **QWebSocketServer**  emits this signal when it negotiates a PSK
        ciphersuite, and therefore a PSK authentication is then required.

        When using PSK, the client must send to the server a valid identity and
        a valid pre shared key, in order for the SSL handshake to continue.
        Applications can provide this information in a slot connected to this
        signal, by filling in the passed **authenticator** object according to
        their needs.

        **Note:** Ignoring this signal, or failing to provide the required
        credentials, will cause the handshake to fail, and therefore the
        connection to be aborted.

        **Note:** The **authenticator** object is owned by the socket and must
        not be deleted by the application.

        This function was introduced in Qt 5.8.

        **See also** **QSslPreSharedKeyAuthenticator**  and
        **QSslSocket::preSharedKeyAuthenticationRequired** ().
        """
        ...

    @property
    def serverError(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#serverError

        **[signal] void
        QWebSocketServer::serverError(QWebSocketProtocol::CloseCode closeCode
        )**

        This signal is emitted when an error occurs during the setup of a
        WebSocket connection. The **closeCode** parameter describes the type of
        error that occurred

        **See also** **errorString** ().
        """
        ...

    @property
    def sslErrors(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocketserver.html#sslErrors

        **[signal] void QWebSocketServer::sslErrors(const QList<QSslError> &
        errors )**

        **QWebSocketServer**  emits this signal after the SSL handshake to
        indicate that one or more errors have occurred while establishing the
        identity of the peer. The errors are usually an indication that
        **QWebSocketServer**  is unable to securely identify the peer. Unless
        any action is taken, the connection will be dropped after this signal
        has been emitted.

        **errors** contains one or more errors that prevent **QSslSocket**  from
        verifying the identity of the peer.

        **See also** **peerVerifyError** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QBasicTimer(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qbasictimer.html

    **Detailed Description**

    This is a fast, lightweight, and low-level class used by Qt internally. We
    recommend using the higher-level **QTimer**  class rather than this class if
    you want to use timers in your applications. Note that this timer is a
    repeating timer that will send subsequent timer events unless the **stop**
    () function is called.

    To use this class, create a QBasicTimer, and call its **start** () function
    with a timeout interval and with a pointer to a **QObject**  subclass. When
    the timer times out it will send a timer event to the **QObject**  subclass.
    The timer can be stopped at any time using **stop** (). **isActive** ()
    returns `true` for a timer that is running; i.e. it has been started, has
    not reached the timeout time, and has not been stopped. The timer's ID can
    be retrieved using **timerId** ().

    Objects of this class cannot be copied, but can be moved, so you can
    maintain a list of basic timers by holding them in container that supports
    move-only types, e.g. std::vector.

    The **Wiggly**  example uses QBasicTimer to repaint a widget at regular
    intervals.

    **See also** **QTimer** , **QTimerEvent** , **QObject::timerEvent** (),
    **Timers** , and **Wiggly Example** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qbasictimer.html#QBasicTimer-1

        **QBasicTimer::QBasicTimer()**

        Constructs a basic timer.

        **See also** **start** ().
        """
        ...

    def swap(self, other: "QBasicTimer") -> None:
        """
        https://doc.qt.io/qt-6/qbasictimer.html#swap

        **[since 5.14] void QBasicTimer::swap(QBasicTimer & other )**

        Swaps string **other** with this string, or **lhs** with **rhs**. This
        operation is very fast and never fails.

        This function was introduced in Qt 5.14.
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qbasictimer.html#stop

        **void QBasicTimer::stop()**

        Stops the timer.

        **See also** **start** () and **isActive** ().
        """
        ...

    @typing.overload
    def start(self, msec: int, timerType: Qt.TimerType, obj: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qbasictimer.html#start

        **void QBasicTimer::start(int msec , QObject * object )**

        Starts (or restarts) the timer with a **msec** milliseconds timeout. The
        timer will be a **Qt::CoarseTimer** . See **Qt::TimerType**  for
        information on the different timer types.

        The given **object** will receive timer events.

        **See also** **stop** (), **isActive** (), **QObject::timerEvent** (),
        and **Qt::CoarseTimer** .
        """
        ...

    @typing.overload
    def start(self, msec: int, obj: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qbasictimer.html#start-1

        **void QBasicTimer::start(int msec , Qt::TimerType timerType , QObject *
        obj )**

        This is an overloaded function.

        Starts (or restarts) the timer with a **msec** milliseconds timeout and
        the given **timerType**. See **Qt::TimerType**  for information on the
        different timer types.

        **obj** will receive timer events.

        **See also** **stop** (), **isActive** (), **QObject::timerEvent** (),
        and **Qt::TimerType** .
        """
        ...

    def timerId(self) -> int:
        """
        https://doc.qt.io/qt-6/qbasictimer.html#timerId

        **int QBasicTimer::timerId() const**

        Returns the timer's ID.

        **See also** **QTimerEvent::timerId** ().
        """
        ...

    def isActive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbasictimer.html#isActive

        **bool QBasicTimer::isActive() const**

        Returns `true` if the timer is running and has not been stopped;
        otherwise returns `false`.

        **See also** **start** () and **stop** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtDesigner import *


class QFormBuilder(QAbstractFormBuilder):
    """
    https://doc.qt.io/qt-6/qformbuilder.html

    **Detailed Description**

    The QFormBuilder class provides a mechanism for dynamically creating user
    interfaces at run-time, based on UI files created with **Qt Designer**. For
    example:

    MyForm::MyForm(**QWidget**  *parent)
                    : **QWidget** (parent)
    {
                    **QFormBuilder**  builder;
                    **QFile**
    file(":/forms/myWidget.ui");
                    file.open(**QFile**
    ::ReadOnly);
                    **QWidget**  *myWidget = builder.load(&file,
    this);
                    file.close();

                    **QVBoxLayout**
    *layout = new **QVBoxLayout** ;
                    layout->addWidget(myWidget);
    setLayout(layout);
                }

    By including the user interface in the example's resources (`myForm.qrc`),
    we ensure that it will be present when the example is run:

    <!DOCTYPE RCC><RCC version="1.0">
            <qresource prefix="/forms">
    <file>mywidget.ui</file>
            </qresource>
            </RCC>

    QFormBuilder extends the **QAbstractFormBuilder**  base class with a number
    of functions that are used to support custom widget plugins:

    * **pluginPaths** () returns the list of paths that the form builder
    searches when loading custom widget plugins.
      * **addPluginPath** () allows
    additional paths to be registered with the form builder.
      *
    **setPluginPath** () is used to replace the existing list of paths with a
    list obtained from some other source.
      * **clearPluginPaths** () removes
    all paths registered with the form builder.
      * **customWidgets** () returns
    a list of interfaces to plugins that can be used to create new instances of
    registered custom widgets.

    The QFormBuilder class is typically used by custom components and
    applications that embed **Qt Designer**. Standalone applications that need
    to dynamically generate user interfaces at run-time use the **QUiLoader**
    class, found in the **QtUiTools**  module.

    **See also** **QAbstractFormBuilder**  and **Qt UI Tools** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qformbuilder.html#QFormBuilder

        **QFormBuilder::QFormBuilder()**

        Constructs a new form builder.
        """
        ...

    def customWidgets(self) -> typing.List[QDesignerCustomWidgetInterface]:
        """
        https://doc.qt.io/qt-6/qformbuilder.html#customWidgets

        **QList<QDesignerCustomWidgetInterface *> QFormBuilder::customWidgets()
        const**

        Returns a list of the available plugins.
        """
        ...

    def setPluginPath(self, pluginPaths: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qformbuilder.html#setPluginPath

        **void QFormBuilder::setPluginPath(const QStringList & pluginPaths )**

        Sets the list of plugin paths to the list specified by **pluginPaths**.

        **See also** **addPluginPath** ().
        """
        ...

    def addPluginPath(self, pluginPath: str) -> None:
        """
        https://doc.qt.io/qt-6/qformbuilder.html#addPluginPath

        **void QFormBuilder::addPluginPath(const QString & pluginPath )**

        Adds a new plugin path specified by **pluginPath** to the list of paths
        that will be searched by the form builder when loading a custom widget
        plugin.

        **See also** **setPluginPath** () and **clearPluginPaths** ().
        """
        ...

    def clearPluginPaths(self) -> None:
        """
        https://doc.qt.io/qt-6/qformbuilder.html#clearPluginPaths

        **void QFormBuilder::clearPluginPaths()**

        Clears the list of paths that the form builder uses to search for custom
        widget plugins.

        **See also** **pluginPaths** ().
        """
        ...

    def pluginPaths(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qformbuilder.html#pluginPaths

        **QStringList QFormBuilder::pluginPaths() const**

        Returns the list of paths the form builder searches for plugins.

        **See also** **addPluginPath** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtXml import *


class QDomEntityReference(QDomNode):
    """
    https://doc.qt.io/qt-6/qdomentityreference.html

    **Detailed Description**

    A QDomEntityReference object may be inserted into the DOM tree when an
    entity reference is in the source document, or when the user wishes to
    insert an entity reference.

    Note that character references and references to predefined entities are
    expanded by the XML processor so that characters are represented by their
    Unicode equivalent rather than by an entity reference.

    Moreover, the XML processor may completely expand references to entities
    while building the DOM tree, instead of providing QDomEntityReference
    objects.

    If it does provide such objects, then for a given entity reference node, it
    may be that there is no entity node representing the referenced entity; but
    if such an entity exists, then the child list of the entity reference node
    is the same as that of the entity node. As with the entity node, all
    descendants of the entity reference are read-only.

    For further information about the Document Object Model see **Level 1**  and
    **Level 2 Core** . For a more general introduction of the DOM implementation
    see the **QDomDocument**  documentation.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomentityreference.html#QDomEntityReference

        **QDomEntityReference::QDomEntityReference()**

        Constructs an empty entity reference. Use
        **QDomDocument::createEntityReference** () to create a entity reference
        with content.
        """
        ...

    @typing.overload
    def __init__(self, x: "QDomEntityReference") -> None:
        """
        https://doc.qt.io/qt-6/qdomentityreference.html#QDomEntityReference-1

        **QDomEntityReference::QDomEntityReference(const QDomEntityReference & x
        )**

        Constructs a copy of **x**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def nodeType(self) -> QDomNode.NodeType:
        """
        https://doc.qt.io/qt-6/qdomentityreference.html#nodeType

        **QDomNode::NodeType QDomEntityReference::nodeType() const**

        Returns `EntityReference`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtWidgets
from PyQt6 import QtSvg
from PyQt6 import QtGui
from PyQt6 import QtCore


class QSvgWidget(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qsvgwidget.html

    **Detailed Description**

    This class enables developers to display SVG drawings alongside standard
    widgets, and is used in much the same way as **QLabel**  is used for
    displaying text and bitmap images.

    Since QSvgWidget is a subclass of **QWidget** , SVG drawings are rendered
    using the properties of the display. More control can be exercised over the
    rendering process with the **QSvgRenderer**  class, as this can be used to
    paint onto other paint devices, such as **QImage**  and QGLWidget. The
    renderer used by the widget can be obtained with the **renderer** ()
    function.

    Each QSvgWidget can be constructed with the file name of a SVG file, or they
    can be constructed without a specific file to render and one can be supplied
    later. The **load** () functions provide two different ways to load an SVG
    file: they accept either the file name of an SVG file or a **QByteArray**
    containing the serialized XML representation of an SVG file.

    By default, the widget provides a size hint to reflect the size of the
    drawing that it displays. If no data has been loaded, the widget provides
    the default **QWidget**  size hint. Subclass this class and reimplement
    **sizeHint** () if you need to customize this behavior.

    **See also** **QSvgRenderer** , **Qt SVG C++ Classes** , and **QPicture** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QtWidgets.QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsvgwidget.html#QSvgWidget

        **QSvgWidget::QSvgWidget(QWidget * parent = nullptr)**

        Constructs a new SVG display widget with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, file: str, parent: typing.Optional[QtWidgets.QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsvgwidget.html#QSvgWidget-1

        **QSvgWidget::QSvgWidget(const QString & file , QWidget * parent =
        nullptr)**

        Constructs a new SVG display widget with the given **parent** and loads
        the contents of the specified **file**.
        """
        ...

    def paintEvent(self, event: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsvgwidget.html#paintEvent

        **[override virtual protected] void QSvgWidget::paintEvent(QPaintEvent *
        event )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    @typing.overload
    def load(self, file: str) -> None:
        """
        https://doc.qt.io/qt-6/qsvgwidget.html#load

        **[slot] void QSvgWidget::load(const QString & file )**

        Loads the contents of the specified SVG **file** and updates the widget.
        """
        ...

    @typing.overload
    def load(self, contents: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qsvgwidget.html#load-1

        **[slot] void QSvgWidget::load(const QByteArray & contents )**

        Loads the specified SVG format **contents** and updates the widget.
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qsvgwidget.html#sizeHint

        **[override virtual] QSize QSvgWidget::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    def renderer(self) -> QtSvg.QSvgRenderer:
        """
        https://doc.qt.io/qt-6/qsvgwidget.html#renderer

        **QSvgRenderer *QSvgWidget::renderer() const**

        Returns the renderer used to display the contents of the widget.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtPositioning import *
import enum


class QNmeaSatelliteInfoSource(QGeoSatelliteInfoSource):
    """
    https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html

    **Detailed Description**

    NMEA is a commonly used protocol for the specification of one's global
    position at a certain point in time. The **QNmeaSatelliteInfoSource**  class
    reads NMEA data and uses it to provide information about satellites in view
    and satellites in use in form of lists of **QGeoSatelliteInfo**  objects.

    A **QNmeaSatelliteInfoSource**  instance operates in either **RealTimeMode**
    or **SimulationMode** . These modes allow NMEA data to be read from either a
    live source of data, or replayed for simulation purposes from previously
    recorded NMEA data.

    The source of NMEA data is set via **setDevice** ().

    Use **startUpdates** () to start receiving regular satellite information
    updates and **stopUpdates** () to stop these updates. If you only require
    updates occasionally, you can call **requestUpdate** () to request a single
    update of both satellites in view and satellites in use.

    The information about satellites in view is received via the
    **satellitesInViewUpdated** () signal.

    The information about satellites in use is received via the
    **satellitesInUseUpdated** () signal.
    """

    class SatelliteInfoParseStatus(enum.Enum):
        NotParsed: QNmeaSatelliteInfoSource = ...
        PartiallyParsed: QNmeaSatelliteInfoSource = ...
        FullyParsed: QNmeaSatelliteInfoSource = ...

    class UpdateMode(enum.Enum):
        RealTimeMode: QNmeaSatelliteInfoSource = ...
        SimulationMode: QNmeaSatelliteInfoSource = ...

    SimulationUpdateInterval: str = ...

    def __init__(
        self,
        mode: "QNmeaSatelliteInfoSource.UpdateMode",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#QNmeaSatelliteInfoS
        ource

        **QNmeaSatelliteInfoSource::QNmeaSatelliteInfoSource(QNmeaSatelliteInfoS
        ource::UpdateMode mode , QObject * parent = nullptr)**

        Constructs a **QNmeaSatelliteInfoSource**  instance with the given
        **parent** and **mode**.
        """
        ...

    def parseSatelliteInfoFromNmea(
        self, data: bytes, size: int, infos: typing.Iterable[QGeoSatelliteInfo]
    ) -> typing.Tuple[
        "QNmeaSatelliteInfoSource.SatelliteInfoParseStatus",
        QGeoSatelliteInfo.SatelliteSystem,
    ]:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#parseSatelliteInfoF
        romNmea

        **[virtual protected] QNmeaSatelliteInfoSource::SatelliteInfoParseStatus
        QNmeaSatelliteInfoSource::parseSatelliteInfoFromNmea(const char * data ,
        int size , QList<QGeoSatelliteInfo> & infos ,
        QGeoSatelliteInfo::SatelliteSystem & system )**

        Parses an NMEA sentence string to extract the information about
        satellites in view.

        The default implementation will parse standard NMEA $GPGSV sentences.
        This method should be reimplemented in a subclass whenever the need to
        deal with non-standard NMEA sentences arises.

        The parser reads **size** bytes from **data** and uses that information
        to fill **infos** list.

        Returns **SatelliteInfoParseStatus**  with parse result. Modifies
        **infos** list in case **PartiallyParsed**  or **FullyParsed**  is
        returned. Also sets the **system** to correct satellite system type.
        This is required to determine the system type in case there are no
        satellites in view.
        """
        ...

    def parseSatellitesInUseFromNmea(
        self, data: bytes, size: int, pnrsInUse: typing.Iterable[int]
    ) -> QGeoSatelliteInfo.SatelliteSystem:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#parseSatellitesInUs
        eFromNmea

        **[virtual protected] QGeoSatelliteInfo::SatelliteSystem
        QNmeaSatelliteInfoSource::parseSatellitesInUseFromNmea(const char * data
        , int size , QList<int> & pnrsInUse )**

        Parses an NMEA sentence string to extract the IDs of satelites in use.

        The default implementation will parse standard NMEA $GPGSA sentences.
        This method should be reimplemented in a subclass whenever the need to
        deal with non-standard NMEA sentences arises.

        The parser reads **size** bytes from **data** and uses that information
        to fill **pnrsInUse** list.

        Returns system type if the sentence was successfully parsed, otherwise
        returns **QGeoSatelliteInfo::Undefined**  and should not modifiy
        **pnrsInUse**.
        """
        ...

    def requestUpdate(self, timeout: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#requestUpdate

        **[override virtual slot] void
        QNmeaSatelliteInfoSource::requestUpdate(int msec = 0)**

        Reimplements: **QGeoSatelliteInfoSource::requestUpdate** (int timeout).
        """
        ...

    def stopUpdates(self) -> None:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#stopUpdates

        **[override virtual slot] void QNmeaSatelliteInfoSource::stopUpdates()**

        Reimplements: **QGeoSatelliteInfoSource::stopUpdates** ().
        """
        ...

    def startUpdates(self) -> None:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#startUpdates

        **[override virtual slot] void
        QNmeaSatelliteInfoSource::startUpdates()**

        Reimplements: **QGeoSatelliteInfoSource::startUpdates** ().
        """
        ...

    def backendProperty(self, name: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#backendProperty

        **[override virtual] QVariant
        QNmeaSatelliteInfoSource::backendProperty(const QString & name ) const**

        Reimplements: **QGeoSatelliteInfoSource::backendProperty(const QString
        &name) const** .

        **See also** **setBackendProperty** ().
        """
        ...

    def setBackendProperty(self, name: str, value: typing.Any) -> bool:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#setBackendProperty

        **[override virtual] bool
        QNmeaSatelliteInfoSource::setBackendProperty(const QString & name ,
        const QVariant & value )**

        Reimplements: **QGeoSatelliteInfoSource::setBackendProperty** (const
        QString &name, const QVariant &value).

        **See also** **backendProperty** ().
        """
        ...

    def error(self) -> QGeoSatelliteInfoSource.Error:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#error

        **[override virtual] QGeoSatelliteInfoSource::Error
        QNmeaSatelliteInfoSource::error() const**

        Reimplements: **QGeoSatelliteInfoSource::error() const** .
        """
        ...

    def minimumUpdateInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#minimumUpdateInterv
        al

        **[override virtual] int
        QNmeaSatelliteInfoSource::minimumUpdateInterval() const**

        Reimplements an access function for property:
        **QGeoSatelliteInfoSource::minimumUpdateInterval** .
        """
        ...

    def setUpdateInterval(self, msec: int) -> None:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#setUpdateInterval

        **[override virtual] void
        QNmeaSatelliteInfoSource::setUpdateInterval(int msec )**

        Reimplements an access function for property:
        **QGeoSatelliteInfoSource::updateInterval** .
        """
        ...

    def device(self) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#device

        **QIODevice *QNmeaSatelliteInfoSource::device() const**

        Returns the NMEA data source.

        **See also** **setDevice** ().
        """
        ...

    def setDevice(self, source: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#setDevice

        **void QNmeaSatelliteInfoSource::setDevice(QIODevice * device )**

        Sets the NMEA data source to **device**. If the device is not open, it
        will be opened in QIODevice::ReadOnly mode.

        The source device can only be set once and must be set before calling
        **startUpdates** () or **requestUpdate** ().

        **Note:** The **device** must emit **QIODevice::readyRead** () for the
        source to be notified when data is available for reading.
        **QNmeaSatelliteInfoSource**  does not assume the ownership of the
        device, and hence does not deallocate it upon destruction.

        **See also** **device** ().
        """
        ...

    def updateMode(self) -> "QNmeaSatelliteInfoSource.UpdateMode":
        """
        https://doc.qt.io/qt-6/qnmeasatelliteinfosource.html#updateMode

        **QNmeaSatelliteInfoSource::UpdateMode
        QNmeaSatelliteInfoSource::updateMode() const**

        Returns the update mode.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtSql import *
import enum


class QSqlDriver(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qsqldriver.html

    **Detailed Description**

    This class should not be used directly. Use **QSqlDatabase**  instead.

    If you want to create your own SQL drivers, you can subclass this class and
    reimplement its pure virtual functions and those virtual functions that you
    need. See **How to Write Your Own Database Driver**  for more information.

    **See also** **QSqlDatabase**  and **QSqlResult** .
    """

    class DbmsType(enum.Enum):
        UnknownDbms: QSqlDriver = ...
        MSSqlServer: QSqlDriver = ...
        MySqlServer: QSqlDriver = ...
        PostgreSQL: QSqlDriver = ...
        Oracle: QSqlDriver = ...
        Sybase: QSqlDriver = ...
        SQLite: QSqlDriver = ...
        Interbase: QSqlDriver = ...
        DB2: QSqlDriver = ...

    class NotificationSource(enum.Enum):
        UnknownSource: QSqlDriver = ...
        SelfSource: QSqlDriver = ...
        OtherSource: QSqlDriver = ...

    class IdentifierType(enum.Enum):
        FieldName: QSqlDriver = ...
        TableName: QSqlDriver = ...

    class StatementType(enum.Enum):
        WhereStatement: QSqlDriver = ...
        SelectStatement: QSqlDriver = ...
        UpdateStatement: QSqlDriver = ...
        InsertStatement: QSqlDriver = ...
        DeleteStatement: QSqlDriver = ...

    class DriverFeature(enum.Enum):
        Transactions: QSqlDriver = ...
        QuerySize: QSqlDriver = ...
        BLOB: QSqlDriver = ...
        Unicode: QSqlDriver = ...
        PreparedQueries: QSqlDriver = ...
        NamedPlaceholders: QSqlDriver = ...
        PositionalPlaceholders: QSqlDriver = ...
        LastInsertId: QSqlDriver = ...
        BatchOperations: QSqlDriver = ...
        SimpleLocking: QSqlDriver = ...
        LowPrecisionNumbers: QSqlDriver = ...
        EventNotifications: QSqlDriver = ...
        FinishQuery: QSqlDriver = ...
        MultipleResultSets: QSqlDriver = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#QSqlDriver

        **QSqlDriver::QSqlDriver(QObject * parent = nullptr)**

        Constructs a new driver with the given **parent**.
        """
        ...

    def maximumIdentifierLength(self, type: "QSqlDriver.IdentifierType") -> int:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#maximumIdentifierLength

        **[virtual, since 6.0] int
        QSqlDriver::maximumIdentifierLength(QSqlDriver::IdentifierType type )
        const**

        Returns the maximum length for the identifier **type** according to the
        database settings. Returns INT_MAX by default if the is no maximum for
        the database.

        This function was introduced in Qt 6.0.
        """
        ...

    def dbmsType(self) -> "QSqlDriver.DbmsType":
        ...

    def numericalPrecisionPolicy(self) -> "QSql.NumericalPrecisionPolicy":
        """
        https://doc.qt.io/qt-6/qsqldriver.html#numericalPrecisionPolicy

        **QSql::NumericalPrecisionPolicy QSqlDriver::numericalPrecisionPolicy()
        const**

        Returns the current default precision policy for the database
        connection.

        **See also** **QSql::NumericalPrecisionPolicy** ,
        **setNumericalPrecisionPolicy** (),
        **QSqlQuery::numericalPrecisionPolicy** (), and
        **QSqlQuery::setNumericalPrecisionPolicy** ().
        """
        ...

    def setNumericalPrecisionPolicy(
        self, precisionPolicy: "QSql.NumericalPrecisionPolicy"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#setNumericalPrecisionPolicy

        **void
        QSqlDriver::setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy
        precisionPolicy )**

        Sets the default numerical precision policy used by queries created by
        this driver to **precisionPolicy**.

        Note: Setting the default precision policy to **precisionPolicy**
        doesn't affect any currently active queries.

        **See also** **QSql::NumericalPrecisionPolicy** ,
        **numericalPrecisionPolicy** (),
        **QSqlQuery::setNumericalPrecisionPolicy** (), and
        **QSqlQuery::numericalPrecisionPolicy** ().
        """
        ...

    def stripDelimiters(
        self, identifier: str, type: "QSqlDriver.IdentifierType"
    ) -> str:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#stripDelimiters

        **[virtual] QString QSqlDriver::stripDelimiters(const QString &
        identifier , QSqlDriver::IdentifierType type ) const**

        Returns the **identifier** with the leading and trailing delimiters
        removed, **identifier** can either be a table name or field name,
        dependent on **type**. If **identifier** does not have leading and
        trailing delimiter characters, **identifier** is returned without
        modification.

        Reimplement this function if you want to provide your own implementation
        in your **QSqlDriver**  subclass,

        **See also** **isIdentifierEscaped** ().
        """
        ...

    def isIdentifierEscaped(
        self, identifier: str, type: "QSqlDriver.IdentifierType"
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#isIdentifierEscaped

        **[virtual] bool QSqlDriver::isIdentifierEscaped(const QString &
        identifier , QSqlDriver::IdentifierType type ) const**

        Returns whether **identifier** is escaped according to the database
        rules. **identifier** can either be a table name or field name,
        dependent on **type**.

        Reimplement this function if you want to provide your own implementation
        in your **QSqlDriver**  subclass,

        **See also** **stripDelimiters** () and **escapeIdentifier** ().
        """
        ...

    def subscribedToNotifications(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#subscribedToNotifications

        **[virtual] QStringList QSqlDriver::subscribedToNotifications() const**

        Returns a list of the names of the event notifications that are
        currently subscribed to.

        Reimplement this function if you want to provide event notification
        support in your own **QSqlDriver**  subclass,

        **See also** **subscribeToNotification** () and
        **unsubscribeFromNotification** ().
        """
        ...

    def unsubscribeFromNotification(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#unsubscribeFromNotification

        **[virtual] bool QSqlDriver::unsubscribeFromNotification(const QString &
        name )**

        This function is called to unsubscribe from event notifications from the
        database. **name** identifies the event notification.

        If successful, return true, otherwise return false.

        The database must be open when this function is called. All subscribed
        event notifications are automatically unsubscribed from when the
        **close** () function is called.

        After calling **this** function the **notification** () signal will no
        longer be emitted when an event notification identified by **name** is
        posted by the database.

        Reimplement this function if you want to provide event notification
        support in your own **QSqlDriver**  subclass,

        **See also** **subscribeToNotification** () and
        **subscribedToNotifications** ().
        """
        ...

    def subscribeToNotification(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#subscribeToNotification

        **[virtual] bool QSqlDriver::subscribeToNotification(const QString &
        name )**

        This function is called to subscribe to event notifications from the
        database. **name** identifies the event notification.

        If successful, return true, otherwise return false.

        The database must be open when this function is called. When the
        database is closed by calling **close** () all subscribed event
        notifications are automatically unsubscribed. Note that calling **open**
        () on an already open database may implicitly cause **close** () to be
        called, which will cause the driver to unsubscribe from all event
        notifications.

        When an event notification identified by **name** is posted by the
        database the **notification** () signal is emitted.

        Reimplement this function if you want to provide event notification
        support in your own **QSqlDriver**  subclass,

        **See also** **unsubscribeFromNotification** (),
        **subscribedToNotifications** (), and **QSqlDriver::hasFeature** ().
        """
        ...

    def setLastError(self, e: "QSqlError") -> None:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#setLastError

        **[virtual protected] void QSqlDriver::setLastError(const QSqlError &
        error )**

        This function is used to set the value of the last error, **error** ,
        that occurred on the database.

        **See also** **lastError** ().
        """
        ...

    def setOpenError(self, e: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#setOpenError

        **[virtual protected] void QSqlDriver::setOpenError(bool error )**

        This function sets the open error state of the database to **error**.
        Derived classes can use this function to report the status of **open**
        (). Note that if **error** is true the open state of the database is set
        to closed (i.e., **isOpen** () returns `false`).

        **See also** **isOpenError** (), **open** (), and **setOpen** ().
        """
        ...

    def setOpen(self, o: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#setOpen

        **[virtual protected] void QSqlDriver::setOpen(bool open )**

        This function sets the open state of the database to **open**. Derived
        classes can use this function to report the status of **open** ().

        **See also** **open** () and **setOpenError** ().
        """
        ...

    def open(
        self,
        db: str,
        user: str = ...,
        password: str = ...,
        host: str = ...,
        port: int = ...,
        options: str = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#open

        **[pure virtual] bool QSqlDriver::open(const QString & db , const
        QString & user = QString(), const QString & password = QString(), const
        QString & host = QString(), int port = -1, const QString & options =
        QString())**

        Derived classes must reimplement this pure virtual function to open a
        database connection on database **db** , using user name **user** ,
        password **password** , host **host** , port **port** and connection
        options **options**.

        The function must return true on success and false on failure.

        **See also** **setOpen** ().
        """
        ...

    def createResult(self) -> "QSqlResult":
        """
        https://doc.qt.io/qt-6/qsqldriver.html#createResult

        **[pure virtual] QSqlResult *QSqlDriver::createResult() const**

        Creates an empty SQL result on the database. Derived classes must
        reimplement this function and return a **QSqlResult**  object
        appropriate for their database to the caller.
        """
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#close

        **[pure virtual] void QSqlDriver::close()**

        Derived classes must reimplement this pure virtual function in order to
        close the database connection. Return true on success, false on failure.

        **See also** **open** () and **setOpen** ().
        """
        ...

    def hasFeature(self, f: "QSqlDriver.DriverFeature") -> bool:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#hasFeature

        **[pure virtual] bool QSqlDriver::hasFeature(QSqlDriver::DriverFeature
        feature ) const**

        Returns `true` if the driver supports feature **feature** ; otherwise
        returns `false`.

        Note that some databases need to be **open** () before this can be
        determined.

        **See also** **DriverFeature** .
        """
        ...

    def handle(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#handle

        **[virtual] QVariant QSqlDriver::handle() const**

        Returns the low-level database handle wrapped in a **QVariant**  or an
        invalid variant if there is no handle.

        **Warning:** Use this with uttermost care and only if you know what
        you're doing.

        **Warning:** The handle returned here can become a stale pointer if the
        connection is modified (for example, if you close the connection).

        **Warning:** The handle can be NULL if the connection is not open yet.

        The handle returned here is database-dependent, you should query the
        type name of the variant before accessing it.

        This example retrieves the handle for a connection to sqlite:

        **QSqlDatabase**  db = **QSqlDatabase** ::database();
            **QVariant**
        v = db.driver()->handle();
            if (v.isValid() && (qstrcmp(v.typeName(),
        "sqlite3*") == 0)) {
                // v.data() returns a pointer to the handle
        sqlite3 *handle = *static_cast<sqlite3 *\\*>(v.data());
                if
        (handle) {
                    // ...
                }
            }

        This snippet returns the handle for PostgreSQL or MySQL:

        if (qstrcmp(v.typeName(), "PGconn*") == 0) {
                PGconn *handle =
        *static_cast<PGconn *\\*>(v.data());
                if (handle) {
                    //
        ...
                }
            }

            if (qstrcmp(v.typeName(), "MYSQL*") == 0) {
        MYSQL *handle = *static_cast<MYSQL *\\*>(v.data());
                if (handle) {
        // ...
                }
            }

        **See also** **QSqlResult::handle** ().
        """
        ...

    def lastError(self) -> "QSqlError":
        """
        https://doc.qt.io/qt-6/qsqldriver.html#lastError

        **QSqlError QSqlDriver::lastError() const**

        Returns a **QSqlError**  object which contains information about the
        last error that occurred on the database.

        **See also** **setLastError** ().
        """
        ...

    def sqlStatement(
        self,
        type: "QSqlDriver.StatementType",
        tableName: str,
        rec: "QSqlRecord",
        preparedStatement: bool,
    ) -> str:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#sqlStatement

        **[virtual] QString QSqlDriver::sqlStatement(QSqlDriver::StatementType
        type , const QString & tableName , const QSqlRecord & rec , bool
        preparedStatement ) const**

        Returns a SQL statement of type **type** for the table **tableName**
        with the values from **rec**. If **preparedStatement** is true, the
        string will contain placeholders instead of values.

        The generated flag in each field of **rec** determines whether the field
        is included in the generated statement.

        This method can be used to manipulate tables without having to worry
        about database-dependent SQL dialects. For non-prepared statements, the
        values will be properly escaped.

        In the WHERE statement, each non-null field of **rec** specifies a
        filter condition of equality to the field value, or if prepared, a
        placeholder. However, prepared or not, a null field specifies the
        condition IS NULL and never introduces a placeholder. The application
        must not attempt to bind data for the null field during execution. The
        field must be set to some non-null value if a placeholder is desired.
        Furthermore, since non-null fields specify equality conditions and SQL
        NULL is not equal to anything, even itself, it is generally not useful
        to bind a null to a placeholder.
        """
        ...

    def escapeIdentifier(
        self, identifier: str, type: "QSqlDriver.IdentifierType"
    ) -> str:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#escapeIdentifier

        **[virtual] QString QSqlDriver::escapeIdentifier(const QString &
        identifier , QSqlDriver::IdentifierType type ) const**

        Returns the **identifier** escaped according to the database rules.
        **identifier** can either be a table name or field name, dependent on
        **type**.

        The default implementation does nothing.

        **See also** **isIdentifierEscaped** ().
        """
        ...

    def formatValue(self, field: "QSqlField", trimStrings: bool = ...) -> str:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#formatValue

        **[virtual] QString QSqlDriver::formatValue(const QSqlField & field ,
        bool trimStrings = false) const**

        Returns a string representation of the **field** value for the database.
        This is used, for example, when constructing INSERT and UPDATE
        statements.

        The default implementation returns the value formatted as a string
        according to the following rules:

        * If **field** is character data, the value is returned enclosed in
        single quotation marks, which is appropriate for many SQL databases. Any
        embedded single-quote characters are escaped (replaced with two single-
        quote characters). If **trimStrings** is true (the default is false),
        all trailing whitespace is trimmed from the field.
          * If **field** is
        date/time data, the value is formatted in ISO format and enclosed in
        single quotation marks. If the date/time data is invalid, "NULL" is
        returned.
          * If **field** is **bytearray**  data, and the driver can
        edit binary fields, the value is formatted as a hexadecimal string.
          *
        For any other field type, toString() is called on its value and the
        result of this is returned.

        **See also** **QVariant::toString** ().
        """
        ...

    def record(self, tableName: str) -> "QSqlRecord":
        """
        https://doc.qt.io/qt-6/qsqldriver.html#record

        **[virtual] QSqlRecord QSqlDriver::record(const QString & tableName )
        const**

        Returns a **QSqlRecord**  populated with the names of the fields in
        table **tableName**. If no such table exists, an empty record is
        returned. The default implementation returns an empty record.
        """
        ...

    def primaryIndex(self, tableName: str) -> "QSqlIndex":
        """
        https://doc.qt.io/qt-6/qsqldriver.html#primaryIndex

        **[virtual] QSqlIndex QSqlDriver::primaryIndex(const QString & tableName
        ) const**

        Returns the primary index for table **tableName**. Returns an empty
        **QSqlIndex**  if the table doesn't have a primary index. The default
        implementation returns an empty index.
        """
        ...

    def tables(self, tableType: "QSql.TableType") -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#tables

        **[virtual] QStringList QSqlDriver::tables(QSql::TableType tableType )
        const**

        Returns a list of the names of the tables in the database. The default
        implementation returns an empty list.

        The **tableType** argument describes what types of tables should be
        returned. Due to binary compatibility, the string contains the value of
        the enum QSql::TableTypes as text. An empty string should be treated as
        **QSql::Tables**  for backward compatibility.
        """
        ...

    def rollbackTransaction(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#rollbackTransaction

        **[virtual] bool QSqlDriver::rollbackTransaction()**

        This function is called to rollback a transaction. If successful, return
        true, otherwise return false. The default implementation does nothing
        and returns `false`.

        **See also** **beginTransaction** () and **commitTransaction** ().
        """
        ...

    def commitTransaction(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#commitTransaction

        **[virtual] bool QSqlDriver::commitTransaction()**

        This function is called to commit a transaction. If successful, return
        true, otherwise return false. The default implementation does nothing
        and returns `false`.

        **See also** **beginTransaction** () and **rollbackTransaction** ().
        """
        ...

    def beginTransaction(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#beginTransaction

        **[virtual] bool QSqlDriver::beginTransaction()**

        This function is called to begin a transaction. If successful, return
        true, otherwise return false. The default implementation does nothing
        and returns `false`.

        **See also** **commitTransaction** () and **rollbackTransaction** ().
        """
        ...

    def isOpenError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#isOpenError

        **bool QSqlDriver::isOpenError() const**

        Returns `true` if the there was an error opening the database
        connection; otherwise returns `false`.
        """
        ...

    def isOpen(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#isOpen

        **[virtual] bool QSqlDriver::isOpen() const**

        Returns `true` if the database connection is open; otherwise returns
        false.
        """
        ...

    @property
    def notification(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsqldriver.html#notification

        **[signal, since 5.0] void QSqlDriver::notification(const QString & name
        , QSqlDriver::NotificationSource source , const QVariant & payload )**

        This signal is emitted when the database posts an event notification
        that the driver subscribes to. **name** identifies the event
        notification, **source** indicates the signal source, **payload** holds
        the extra data optionally delivered with the notification.

        This function was introduced in Qt 5.0.

        **See also** **subscribeToNotification** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6.QtPrintSupport import *


class QPrinterInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qprinterinfo.html

    **Detailed Description**

    Use the static functions to generate a list of QPrinterInfo objects. Each
    QPrinterInfo object in the list represents a single printer and can be
    queried for name, supported paper sizes, and whether or not it is the
    default printer.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#QPrinterInfo

        **QPrinterInfo::QPrinterInfo()**

        Constructs an empty QPrinterInfo object.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, src: "QPrinterInfo") -> None:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#QPrinterInfo-1

        **QPrinterInfo::QPrinterInfo(const QPrinterInfo & other )**

        Constructs a copy of **other**.
        """
        ...

    @typing.overload
    def __init__(self, printer: QPrinter) -> None:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#QPrinterInfo-2

        **QPrinterInfo::QPrinterInfo(const QPrinter & printer )**

        Constructs a QPrinterInfo object from **printer**.
        """
        ...

    def supportedColorModes(self) -> typing.List[QPrinter.ColorMode]:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#supportedColorModes

        **[since 5.13] QList<QPrinter::ColorMode>
        QPrinterInfo::supportedColorModes() const**

        Returns the supported color modes of this printer.

        This function was introduced in Qt 5.13.
        """
        ...

    def defaultColorMode(self) -> QPrinter.ColorMode:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#defaultColorMode

        **[since 5.13] QPrinter::ColorMode QPrinterInfo::defaultColorMode()
        const**

        Returns the default color mode of this printer.

        This function was introduced in Qt 5.13.
        """
        ...

    def supportedDuplexModes(self) -> typing.List[QPrinter.DuplexMode]:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#supportedDuplexModes

        **[since 5.4] QList<QPrinter::DuplexMode>
        QPrinterInfo::supportedDuplexModes() const**

        Returns a list of duplex modes supported by this printer.

        This function was introduced in Qt 5.4.
        """
        ...

    def defaultDuplexMode(self) -> QPrinter.DuplexMode:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#defaultDuplexMode

        **[since 5.4] QPrinter::DuplexMode QPrinterInfo::defaultDuplexMode()
        const**

        Returns the default duplex mode of this printer.

        This function was introduced in Qt 5.4.
        """
        ...

    @staticmethod
    def defaultPrinterName() -> str:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#defaultPrinterName

        **[static, since 5.3] QString QPrinterInfo::defaultPrinterName()**

        Returns the current default printer name.

        This function was introduced in Qt 5.3.
        """
        ...

    @staticmethod
    def availablePrinterNames() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#availablePrinterNames

        **[static, since 5.3] QStringList
        QPrinterInfo::availablePrinterNames()**

        Returns a list of all the available Printer Names on this system.

        It is recommended to use this instead of **availablePrinters** () as it
        will be faster on most systems.

        Note that the list may become outdated if changes are made on the local
        system or remote print server. Only instantiate required
        **QPrinterInfo**  instances when needed, and always check for validity
        before calling.

        This function was introduced in Qt 5.3.
        """
        ...

    def supportedResolutions(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#supportedResolutions

        **[since 5.3] QList<int> QPrinterInfo::supportedResolutions() const**

        Returns a list of resolutions supported by this printer.

        This function was introduced in Qt 5.3.
        """
        ...

    def maximumPhysicalPageSize(self) -> QtGui.QPageSize:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#maximumPhysicalPageSize

        **[since 5.3] QPageSize QPrinterInfo::maximumPhysicalPageSize() const**

        Returns the maximum physical page size supported by this printer.

        This function was introduced in Qt 5.3.

        **See also** **minimumPhysicalPageSize** ().
        """
        ...

    def minimumPhysicalPageSize(self) -> QtGui.QPageSize:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#minimumPhysicalPageSize

        **[since 5.3] QPageSize QPrinterInfo::minimumPhysicalPageSize() const**

        Returns the minimum physical page size supported by this printer.

        This function was introduced in Qt 5.3.

        **See also** **maximumPhysicalPageSize** ().
        """
        ...

    def supportsCustomPageSizes(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#supportsCustomPageSizes

        **[since 5.3] bool QPrinterInfo::supportsCustomPageSizes() const**

        Returns whether this printer supports custom page sizes.

        This function was introduced in Qt 5.3.
        """
        ...

    def defaultPageSize(self) -> QtGui.QPageSize:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#defaultPageSize

        **[since 5.3] QPageSize QPrinterInfo::defaultPageSize() const**

        Returns the current default Page Size for this printer.

        This function was introduced in Qt 5.3.
        """
        ...

    def supportedPageSizes(self) -> typing.List[QtGui.QPageSize]:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#supportedPageSizes

        **[since 5.3] QList<QPageSize> QPrinterInfo::supportedPageSizes()
        const**

        Returns a list of Page Sizes supported by this printer.

        This function was introduced in Qt 5.3.
        """
        ...

    def state(self) -> QPrinter.PrinterState:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#state

        **[since 5.3] QPrinter::PrinterState QPrinterInfo::state() const**

        Returns the current state of this printer.

        This state may not always be accurate, depending on the platform,
        printer driver, or printer itself.

        This function was introduced in Qt 5.3.
        """
        ...

    def isRemote(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#isRemote

        **[since 5.3] bool QPrinterInfo::isRemote() const**

        Returns whether this printer is a remote network printer.

        This function was introduced in Qt 5.3.
        """
        ...

    @staticmethod
    def printerInfo(printerName: str) -> "QPrinterInfo":
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#printerInfo

        **[static, since 5.0] QPrinterInfo QPrinterInfo::printerInfo(const
        QString & printerName )**

        Returns the printer **printerName**.

        The return value should be checked using **isNull** () before being
        used, in case the named printer does not exist.

        This function was introduced in Qt 5.0.

        **See also** **isNull** ().
        """
        ...

    def makeAndModel(self) -> str:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#makeAndModel

        **[since 5.0] QString QPrinterInfo::makeAndModel() const**

        Returns the human-readable make and model of the printer.

        This function was introduced in Qt 5.0.
        """
        ...

    def location(self) -> str:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#location

        **[since 5.0] QString QPrinterInfo::location() const**

        Returns the human-readable location of the printer.

        This function was introduced in Qt 5.0.
        """
        ...

    def description(self) -> str:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#description

        **[since 5.0] QString QPrinterInfo::description() const**

        Returns the human-readable description of the printer.

        This function was introduced in Qt 5.0.

        **See also** **QPrinterInfo::printerName** ().
        """
        ...

    @staticmethod
    def defaultPrinter() -> "QPrinterInfo":
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#defaultPrinter

        **[static] QPrinterInfo QPrinterInfo::defaultPrinter()**

        Returns the default printer on the system.

        The return value should be checked using **isNull** () before being
        used, in case there is no default printer.

        On some systems it is possible for there to be available printers but
        none of them set to be the default printer.

        **See also** **isNull** (), **isDefault** (), and **availablePrinters**
        ().
        """
        ...

    @staticmethod
    def availablePrinters() -> typing.List["QPrinterInfo"]:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#availablePrinters

        **[static] QList<QPrinterInfo> QPrinterInfo::availablePrinters()**

        Returns a list of **QPrinterInfo**  objects for all the available
        printers on this system.

        It is NOT recommended to use this as creating each printer instance may
        take a long time, especially if there are remote networked printers, and
        retained instances may become outdated if changes are made on the local
        system or remote print server. Use **availablePrinterNames** () instead
        and only instantiate printer instances as you need them.
        """
        ...

    def isDefault(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#isDefault

        **bool QPrinterInfo::isDefault() const**

        Returns whether this printer is currently the default printer.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#isNull

        **bool QPrinterInfo::isNull() const**

        Returns whether this **QPrinterInfo**  object holds a printer
        definition.

        An empty **QPrinterInfo**  object could result for example from calling
        **defaultPrinter** () when there are no printers on the system.
        """
        ...

    def printerName(self) -> str:
        """
        https://doc.qt.io/qt-6/qprinterinfo.html#printerName

        **QString QPrinterInfo::printerName() const**

        Returns the name of the printer.

        This is a unique id to identify the printer and may not be human-
        readable.

        **See also** **QPrinterInfo::description** () and
        **QPrinter::setPrinterName** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QButtonGroup(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qbuttongroup.html

    **Detailed Description**

    QButtonGroup provides an abstract container into which button widgets can be
    placed. It does not provide a visual representation of this container (see
    **QGroupBox**  for a container widget), but instead manages the states of
    each of the buttons in the group.

    An **exclusive**  button group switches off all checkable (toggle) buttons
    except the one that has been clicked. By default, a button group is
    exclusive. The buttons in a button group are usually checkable
    **QPushButton** s, **QCheckBox** es (normally for non-exclusive button
    groups), or **QRadioButton** s. If you create an exclusive button group, you
    should ensure that one of the buttons in the group is initially checked;
    otherwise, the group will initially be in a state where no buttons are
    checked.

    A button can be added to the group with **addButton** () and removed with
    **removeButton** (). If the group is exclusive, the currently checked button
    is available with **checkedButton** (). If a button is clicked, the
    **buttonClicked** () signal is emitted; for a checkable button in an
    exclusive group this means that the button has been checked. The list of
    buttons in the group is returned by **buttons** ().

    In addition, QButtonGroup can map between integers and buttons. You can
    assign an integer id to a button with **setId** (), and retrieve it with
    **id** (). The id of the currently checked button is available with
    **checkedId** (), and there is an overloaded signal **buttonClicked** ()
    which emits the id of the button. The id `-1` is reserved by QButtonGroup to
    mean "no such button". The purpose of the mapping mechanism is to simplify
    the representation of enum values in a user interface.

    **See also** **QGroupBox** , **QPushButton** , **QCheckBox** , and
    **QRadioButton** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#QButtonGroup

        **QButtonGroup::QButtonGroup(QObject * parent = nullptr)**

        Constructs a new, empty button group with the given **parent**.

        **See also** **addButton** () and **setExclusive** ().
        """
        ...

    def checkedId(self) -> int:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#checkedId

        **int QButtonGroup::checkedId() const**

        Returns the id of the **checkedButton** (), or -1 if no button is
        checked.

        **See also** **setId** ().
        """
        ...

    def id(self, button: QAbstractButton) -> int:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#id

        **int QButtonGroup::id(QAbstractButton * button ) const**

        Returns the id for the specified **button** , or -1 if no such button
        exists.

        **See also** **setId** ().
        """
        ...

    def setId(self, button: QAbstractButton, id: int) -> None:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#setId

        **void QButtonGroup::setId(QAbstractButton * button , int id )**

        Sets the **id** for the specified **button**. Note that **id** cannot be
        -1.

        **See also** **id** ().
        """
        ...

    def checkedButton(self) -> QAbstractButton:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#checkedButton

        **QAbstractButton *QButtonGroup::checkedButton() const**

        Returns the button group's checked button, or `nullptr` if no buttons
        are checked.

        **See also** **buttonClicked** ().
        """
        ...

    def button(self, id: int) -> QAbstractButton:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#button

        **QAbstractButton *QButtonGroup::button(int id ) const**

        Returns the button with the specified **id** , or `nullptr` if no such
        button exists.
        """
        ...

    def buttons(self) -> typing.List[QAbstractButton]:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#buttons

        **QList<QAbstractButton *> QButtonGroup::buttons() const**

        Returns the button group's list of buttons. This may be empty.

        **See also** **addButton** () and **removeButton** ().
        """
        ...

    def removeButton(self, a0: QAbstractButton) -> None:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#removeButton

        **void QButtonGroup::removeButton(QAbstractButton * button )**

        Removes the given **button** from the button group.

        **See also** **addButton** () and **buttons** ().
        """
        ...

    def addButton(self, a0: QAbstractButton, id: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#addButton

        **void QButtonGroup::addButton(QAbstractButton * button , int id = -1)**

        Adds the given **button** to the button group. If **id** is -1, an id
        will be assigned to the button. Automatically assigned ids are
        guaranteed to be negative, starting with -2. If you are assigning your
        own ids, use positive values to avoid conflicts.

        **See also** **removeButton** () and **buttons** ().
        """
        ...

    def exclusive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#exclusive-prop

        **exclusive : bool**

        This property holds whether the button group is exclusive

        If this property is `true`, then only one button in the group can be
        checked at any given time. The user can click on any button to check it,
        and that button will replace the existing one as the checked button in
        the group.

        In an exclusive group, the user cannot uncheck the currently checked
        button by clicking on it; instead, another button in the group must be
        clicked to set the new checked button for that group.

        By default, this property is `true`.

        **Access functions:**

        bool **exclusive** () const
        void **setExclusive** (bool)

        **Member Function Documentation**
        """
        ...

    def setExclusive(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#exclusive-prop

        **exclusive : bool**

        This property holds whether the button group is exclusive

        If this property is `true`, then only one button in the group can be
        checked at any given time. The user can click on any button to check it,
        and that button will replace the existing one as the checked button in
        the group.

        In an exclusive group, the user cannot uncheck the currently checked
        button by clicking on it; instead, another button in the group must be
        clicked to set the new checked button for that group.

        By default, this property is `true`.

        **Access functions:**

        bool **exclusive** () const
        void **setExclusive** (bool)

        **Member Function Documentation**
        """
        ...

    @property
    def buttonClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#buttonClicked

        **[signal] void QButtonGroup::buttonClicked(QAbstractButton * button )**

        This signal is emitted when the given **button** is clicked. A button is
        clicked when it is first pressed and then released, when its shortcut
        key is typed, or when **QAbstractButton::click** () or
        **QAbstractButton::animateClick** () is programmatically called.

        **See also** **checkedButton** () and **QAbstractButton::clicked** ().
        """
        ...

    @property
    def buttonPressed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#buttonPressed

        **[signal] void QButtonGroup::buttonPressed(QAbstractButton * button )**

        This signal is emitted when the given **button** is pressed down.

        **See also** **QAbstractButton::pressed** ().
        """
        ...

    @property
    def buttonReleased(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#buttonReleased

        **[signal] void QButtonGroup::buttonReleased(QAbstractButton * button
        )**

        This signal is emitted when the given **button** is released.

        **See also** **QAbstractButton::released** ().
        """
        ...

    @property
    def buttonToggled(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#buttonToggled

        **[signal, since 5.2] void QButtonGroup::buttonToggled(QAbstractButton *
        button , bool checked )**

        This signal is emitted when the given **button** is toggled. **checked**
        is true if the button is checked, or false if the button is unchecked.

        This function was introduced in Qt 5.2.

        **See also** **QAbstractButton::toggled** ().
        """
        ...

    @property
    def idClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#idClicked

        **[signal, since 5.15] void QButtonGroup::idClicked(int id )**

        This signal is emitted when a button with the given **id** is clicked.

        This function was introduced in Qt 5.15.

        **See also** **checkedButton** () and **QAbstractButton::clicked** ().
        """
        ...

    @property
    def idPressed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#idPressed

        **[signal, since 5.15] void QButtonGroup::idPressed(int id )**

        This signal is emitted when a button with the given **id** is pressed
        down.

        This function was introduced in Qt 5.15.

        **See also** **QAbstractButton::pressed** ().
        """
        ...

    @property
    def idReleased(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#idReleased

        **[signal, since 5.15] void QButtonGroup::idReleased(int id )**

        This signal is emitted when a button with the given **id** is released.

        This function was introduced in Qt 5.15.

        **See also** **QAbstractButton::released** ().
        """
        ...

    @property
    def idToggled(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbuttongroup.html#idToggled

        **[signal, since 5.15] void QButtonGroup::idToggled(int id , bool
        checked )**

        This signal is emitted when a button with the given **id** is toggled.
        **checked** is true if the button is checked, or false if the button is
        unchecked.

        This function was introduced in Qt 5.15.

        **See also** **QAbstractButton::toggled** ().
        """
        ...
